@@ -23,8 +23,10 @@ package org.apache.qpid.server.store.berkeleydb.replication;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
+
 import java.net.InetSocketAddress;
 import java.net.SocketTimeoutException;
+
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
@@ -34,6 +36,7 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.Callable;
+import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.CopyOnWriteArraySet;
@@ -47,14 +50,49 @@ import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicReference;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
-import com.google.common.util.concurrent.ListeningExecutorService;
-import com.google.common.util.concurrent.MoreExecutors;
-import com.sleepycat.je.*;
+
+import com.sleepycat.je.CheckpointConfig;
+import com.sleepycat.je.Database;
+import com.sleepycat.je.DatabaseConfig;
+import com.sleepycat.je.DatabaseEntry;
+import com.sleepycat.je.DatabaseException;
+import com.sleepycat.je.DbInternal;
+import com.sleepycat.je.Durability;
 import com.sleepycat.je.Durability.ReplicaAckPolicy;
 import com.sleepycat.je.Durability.SyncPolicy;
-import com.sleepycat.je.rep.*;
+import com.sleepycat.je.EnvironmentConfig;
+import com.sleepycat.je.EnvironmentFailureException;
+import com.sleepycat.je.EnvironmentMutableConfig;
+import com.sleepycat.je.ExceptionEvent;
+import com.sleepycat.je.LogWriteException;
+import com.sleepycat.je.Sequence;
+import com.sleepycat.je.SequenceConfig;
+import com.sleepycat.je.Transaction;
+import com.sleepycat.je.TransactionConfig;
+import com.sleepycat.je.rep.AppStateMonitor;
+import com.sleepycat.je.rep.InsufficientAcksException;
+import com.sleepycat.je.rep.InsufficientLogException;
+import com.sleepycat.je.rep.InsufficientReplicasException;
+import com.sleepycat.je.rep.MasterStateException;
+import com.sleepycat.je.rep.MemberNotFoundException;
+import com.sleepycat.je.rep.NetworkRestore;
+import com.sleepycat.je.rep.NetworkRestoreConfig;
+import com.sleepycat.je.rep.NoConsistencyRequiredPolicy;
+import com.sleepycat.je.rep.NodeState;
+import com.sleepycat.je.rep.NodeType;
+import com.sleepycat.je.rep.RepInternal;
+import com.sleepycat.je.rep.ReplicaConsistencyException;
+import com.sleepycat.je.rep.ReplicaWriteException;
+import com.sleepycat.je.rep.ReplicatedEnvironment;
+import com.sleepycat.je.rep.ReplicationConfig;
+import com.sleepycat.je.rep.ReplicationGroup;
+import com.sleepycat.je.rep.ReplicationMutableConfig;
+import com.sleepycat.je.rep.ReplicationNode;
+import com.sleepycat.je.rep.RestartRequiredException;
+import com.sleepycat.je.rep.RollbackException;
+import com.sleepycat.je.rep.StateChangeEvent;
+import com.sleepycat.je.rep.StateChangeListener;
+import com.sleepycat.je.rep.UnknownMasterException;
 import com.sleepycat.je.rep.impl.node.NameIdPair;
 import com.sleepycat.je.rep.util.DbPing;
 import com.sleepycat.je.rep.util.ReplicationGroupAdmin;
@@ -64,6 +102,7 @@ import com.sleepycat.je.rep.utilint.ServiceDispatcher.ServiceConnectFailedExcept
 import com.sleepycat.je.rep.vlsn.VLSNRange;
 import com.sleepycat.je.utilint.PropUtil;
 import com.sleepycat.je.utilint.VLSN;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -83,6 +122,7 @@ import org.apache.qpid.server.util.DaemonThreadFactory;
 import org.apache.qpid.server.util.ExternalServiceException;
 import org.apache.qpid.server.util.ExternalServiceTimeoutException;
 import org.apache.qpid.server.util.ServerScopedRuntimeException;
+import org.apache.qpid.server.virtualhost.berkeleydb.BDBVirtualHost;
 
 public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChangeListener
 {
@@ -93,6 +133,7 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
     public static final String ENVIRONMENT_RESTART_RETRY_LIMIT_PROPERTY_NAME = "qpid.bdb.ha.environment_restart_retry_limit";
     public static final String EXECUTOR_SHUTDOWN_TIMEOUT_PROPERTY_NAME = "qpid.bdb.ha.executor_shutdown_timeout";
     public static final String DISABLE_COALESCING_COMMITTER_PROPERTY_NAME = "qpid.bdb.ha.disable_coalescing_committer";
+    public static final String NO_SYNC_TX_DURABILITY_PROPERTY_NAME = "qpid.bdb.ha.noSyncTxDurablity";
 
     private static final Logger LOGGER = LoggerFactory.getLogger(ReplicatedEnvironmentFacade.class);
 
@@ -103,6 +144,8 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
     private static final int DEFAULT_ENVIRONMENT_RESTART_RETRY_LIMIT = 3;
     private static final int DEFAULT_EXECUTOR_SHUTDOWN_TIMEOUT = 5000;
     private static final boolean DEFAULT_DISABLE_COALESCING_COMMITTER = false;
+    private static final String DEFAULT_NO_SYNC_TX_DURABILITY_PROPERTY_NAME = "NO_SYNC,NO_SYNC,NONE";
+    private static final String DEFAULT_SYNC_TX_DURABILITY_PROPERTY_NAME = "SYNC,NO_SYNC,NONE";
 
     /** Length of time allowed for a master transfer to complete before the operation will timeout */
     private final int _masterTransferTimeout;
@@ -139,6 +182,8 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
 
     private final boolean _disableCoalescingCommiter;
 
+    private final Durability _noSyncTxDurability;
+
     private final int _logHandlerCleanerProtectedFilesLimit;
 
     static final SyncPolicy LOCAL_TRANSACTION_SYNCHRONIZATION_POLICY = SyncPolicy.SYNC;
@@ -146,7 +191,7 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
     public static final ReplicaAckPolicy REPLICA_REPLICA_ACKNOWLEDGMENT_POLICY = ReplicaAckPolicy.SIMPLE_MAJORITY;
 
     @SuppressWarnings("serial")
-    private static final Map<String, String> REPCONFIG_DEFAULTS = Collections.unmodifiableMap(new HashMap<String, String>()
+    private static final Map<String, String> REPCONFIG_DEFAULTS = Collections.unmodifiableMap(new HashMap<>()
     {{
         /**
          * Parameter decreased as the 24h default may lead very large log files for most users.
@@ -174,13 +219,13 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
          * is scheduled to become default after JE 5.1.
          */
         put(ReplicationConfig.PROTOCOL_OLD_STRING_ENCODING, Boolean.FALSE.toString());
-         /**
-          * Allow Replica to proceed with transactions regardless of the state of a Replica
-          * At the moment we do not read or write databases on Replicas.
-          * Setting consistency policy to NoConsistencyRequiredPolicy
-          * would allow to create transaction on Replica immediately.
-          * Any followed write operation would fail with ReplicaWriteException.
-          */
+        /**
+         * Allow Replica to proceed with transactions regardless of the state of a Replica
+         * At the moment we do not read or write databases on Replicas.
+         * Setting consistency policy to NoConsistencyRequiredPolicy
+         * would allow to create transaction on Replica immediately.
+         * Any followed write operation would fail with ReplicaWriteException.
+         */
         put(ReplicationConfig.CONSISTENCY_POLICY, NoConsistencyRequiredPolicy.NAME);
     }});
 
@@ -206,7 +251,7 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
     private final File _environmentDirectory;
 
     private final ExecutorService _environmentJobExecutor;
-    private final ListeningExecutorService _stateChangeExecutor;
+    private final ExecutorService _stateChangeExecutor;
 
     /**
      * Executor used to learn about changes in the group.  Number of threads in the pool is maintained dynamically
@@ -215,16 +260,16 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
      * transfer master operation.
      */
     private final ScheduledThreadPoolExecutor _groupChangeExecutor;
-    private final AtomicReference<State> _state = new AtomicReference<State>(State.OPENING);
-    private final ConcurrentMap<String, ReplicationNode> _remoteReplicationNodes = new ConcurrentHashMap<String, ReplicationNode>();
-    private final AtomicReference<ReplicationGroupListener> _replicationGroupListener = new AtomicReference<ReplicationGroupListener>();
-    private final AtomicReference<StateChangeListener> _stateChangeListener = new AtomicReference<StateChangeListener>();
+    private final AtomicReference<State> _state = new AtomicReference<>(State.OPENING);
+    private final ConcurrentMap<String, ReplicationNode> _remoteReplicationNodes = new ConcurrentHashMap<>();
+    private final AtomicReference<ReplicationGroupListener> _replicationGroupListener = new AtomicReference<>();
+    private final AtomicReference<StateChangeListener> _stateChangeListener = new AtomicReference<>();
     private final Durability _defaultDurability;
     private final ConcurrentMap<String, Database> _cachedDatabases = new ConcurrentHashMap<>();
     private final ConcurrentMap<DatabaseEntry, Sequence> _cachedSequences = new ConcurrentHashMap<>();
     private final AtomicReference<ReplicatedEnvironment> _environment = new AtomicReference<>();
 
-    private final Set<String> _permittedNodes = new CopyOnWriteArraySet<String>();
+    private final Set<String> _permittedNodes = new CopyOnWriteArraySet<>();
     private volatile Durability _realMessageStoreDurability = null;
     private volatile Durability _messageStoreDurability;
     private volatile CoalescingCommiter _coalescingCommiter = null;
@@ -281,31 +326,29 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
 
         // we rely on this executor being single-threaded as we need to restart and mutate the environment from one thread only
         _environmentJobExecutor = Executors.newSingleThreadExecutor(new DaemonThreadFactory("Environment-" + _prettyGroupNodeName));
-        _stateChangeExecutor = MoreExecutors.listeningDecorator(Executors.newSingleThreadExecutor(new DaemonThreadFactory("StateChange-" + _prettyGroupNodeName)));
+        _stateChangeExecutor = Executors.newSingleThreadExecutor(new DaemonThreadFactory("StateChange-" + _prettyGroupNodeName));
         _groupChangeExecutor = new ScheduledThreadPoolExecutor(2, new DaemonThreadFactory("Group-Change-Learner:" + _prettyGroupNodeName));
         _disableCoalescingCommiter = configuration.getFacadeParameter(Boolean.class,DISABLE_COALESCING_COMMITTER_PROPERTY_NAME, DEFAULT_DISABLE_COALESCING_COMMITTER);
+        _noSyncTxDurability = Durability.parse(configuration.getFacadeParameter(String.class, NO_SYNC_TX_DURABILITY_PROPERTY_NAME, getDefaultDurability(_disableCoalescingCommiter)));
 
         // create environment in a separate thread to avoid renaming of the current thread by JE
         EnvHomeRegistry.getInstance().registerHome(_environmentDirectory);
         boolean success = false;
         try
         {
-            createEnvironment(true, new Runnable(){
-                @Override
-                public void run()
+            createEnvironment(true, () ->
+            {
+                populateExistingRemoteReplicationNodes();
+                int numberOfRemoteNodes = _remoteReplicationNodes.size();
+                if (numberOfRemoteNodes > 0)
                 {
-                    populateExistingRemoteReplicationNodes();
-                    int numberOfRemoteNodes = _remoteReplicationNodes.size();
-                    if (numberOfRemoteNodes > 0)
-                    {
-                        int newPoolSize = numberOfRemoteNodes
-                                          + 1 /* for this node */
-                                          + 1 /* for coordination */;
-                        _groupChangeExecutor.setCorePoolSize(newPoolSize);
-                        LOGGER.debug("Setting group change executor core pool size to {}", newPoolSize);
-                    }
-                    _groupChangeExecutor.submit(new RemoteNodeStateLearner());
+                    int newPoolSize = numberOfRemoteNodes
+                                      + 1 /* for this node */
+                                      + 1 /* for coordination */;
+                    _groupChangeExecutor.setCorePoolSize(newPoolSize);
+                    LOGGER.debug("Setting group change executor core pool size to {}", newPoolSize);
                 }
+                _groupChangeExecutor.submit(new RemoteNodeStateLearner());
             });
             success = true;
         }
@@ -318,6 +361,18 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
         }
     }
 
+    private String getDefaultDurability(final boolean disableCoalescingCommiter)
+    {
+        if (disableCoalescingCommiter)
+        {
+            return DEFAULT_SYNC_TX_DURABILITY_PROPERTY_NAME;
+        }
+        else
+        {
+            return DEFAULT_NO_SYNC_TX_DURABILITY_PROPERTY_NAME;
+        }
+    }
+
     @Override
     public Transaction beginTransaction(TransactionConfig transactionConfig)
     {
@@ -325,47 +380,55 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
     }
 
     @Override
-    public void commit(final Transaction tx, boolean syncCommit)
+    public void commit(final Transaction tx)
     {
-        try
-        {
-            // Using commit() instead of commitNoSync() for the HA store to allow
-            // the HA durability configuration to influence resulting behaviour.
-            tx.commit(_realMessageStoreDurability);
-        }
-        catch (DatabaseException de)
-        {
-            throw handleDatabaseException("Got DatabaseException on commit, closing environment", de);
-        }
+        commitInternal(tx, _realMessageStoreDurability);
 
         if (_coalescingCommiter != null && _realMessageStoreDurability.getLocalSync() == SyncPolicy.NO_SYNC
                 && _messageStoreDurability.getLocalSync() == SyncPolicy.SYNC)
         {
-            _coalescingCommiter.commit(tx, syncCommit);
+            _coalescingCommiter.commit(tx, true);
         }
 
     }
 
-    @Override
-    public <X> ListenableFuture<X> commitAsync(final Transaction tx, final X val)
+    private void commitInternal(final Transaction tx, final Durability realMessageStoreDurability)
     {
         try
         {
             // Using commit() instead of commitNoSync() for the HA store to allow
             // the HA durability configuration to influence resulting behaviour.
-            tx.commit(_realMessageStoreDurability);
+            tx.commit(realMessageStoreDurability);
         }
         catch (DatabaseException de)
         {
             throw handleDatabaseException("Got DatabaseException on commit, closing environment", de);
         }
+    }
+
+    @Override
+    public void commitNoSync(final Transaction tx)
+    {
+        commitInternal(tx, _noSyncTxDurability);
+
+        if (_coalescingCommiter != null && _realMessageStoreDurability.getLocalSync() == SyncPolicy.NO_SYNC
+            && _messageStoreDurability.getLocalSync() == SyncPolicy.SYNC)
+        {
+            _coalescingCommiter.commit(tx, false);
+        }
+    }
+
+    @Override
+    public <X> CompletableFuture<X> commitAsync(final Transaction tx, final X val)
+    {
+        commitInternal(tx, _realMessageStoreDurability);
 
         if (_coalescingCommiter != null && _realMessageStoreDurability.getLocalSync() == SyncPolicy.NO_SYNC
             && _messageStoreDurability.getLocalSync() == SyncPolicy.SYNC)
         {
             return _coalescingCommiter.commitAsync(tx, val);
         }
-        return Futures.immediateFuture(val);
+        return CompletableFuture.completedFuture(val);
     }
 
     @Override
@@ -523,65 +586,57 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
             // Tell the virtualhostnode that we are no longer attached to the group.  It will close the virtualhost,
             // closing the connections, housekeeping etc meaning all transactions are finished before we
             // restart the environment.
-            _stateChangeExecutor.submit(new Callable<Void>()
+            CompletableFuture.supplyAsync(() ->
             {
-                @Override
-                public Void call() throws Exception
+                StateChangeListener listener = _stateChangeListener.get();
+                if (listener != null && _state.get() == State.RESTARTING)
                 {
-                    StateChangeListener listener = _stateChangeListener.get();
-                    if (listener != null && _state.get() == State.RESTARTING)
+                    try
                     {
-                        try
-                        {
-                            StateChangeEvent detached = new StateChangeEvent(ReplicatedEnvironment.State.DETACHED, NameIdPair.NULL);
-                            listener.stateChange(detached);
-                        }
-                        catch (Throwable t)
-                        {
-                            handleUncaughtExceptionInExecutorService(t);
-                        }
+                        StateChangeEvent detached = new StateChangeEvent(ReplicatedEnvironment.State.DETACHED, NameIdPair.NULL);
+                        listener.stateChange(detached);
+                    }
+                    catch (Throwable t)
+                    {
+                        handleUncaughtExceptionInExecutorService(t);
                     }
-
-                    return null;
                 }
-            }).addListener(new Runnable()
-            {
-                @Override
-                public void run()
-                {
-                    int attemptNumber = 1;
-                    boolean restarted = false;
-                    Exception lastException = null;
-                    while(_state.get() == State.RESTARTING && attemptNumber <= _environmentRestartRetryLimit)
-                    {
-                        try
-                        {
-                            restartEnvironment();
-                            restarted = true;
-                            break;
-                        }
-                        catch(EnvironmentFailureException e)
-                        {
-                            LOGGER.warn("Failure whilst trying to restart environment (attempt number "
-                                    + "{} of {})", attemptNumber, _environmentRestartRetryLimit, e);
-                            lastException = e;
-                        }
-                        catch (Exception e)
-                        {
-                            LOGGER.error("Fatal failure whilst trying to restart environment", e);
-                            lastException = e;
-                            break;
-                        }
-                        attemptNumber++;
-                    }
 
-                    if (!restarted)
+                return null;
+            }, _stateChangeExecutor).thenRunAsync(() ->
+            {
+                int attemptNumber = 1;
+                boolean restarted = false;
+                Exception lastException = null;
+                while(_state.get() == State.RESTARTING && attemptNumber <= _environmentRestartRetryLimit)
+                {
+                    try
                     {
-                        LOGGER.error("Failed to restart environment.");
-                        if (lastException != null)
-                        {
-                            handleUncaughtExceptionInExecutorService(lastException);
-                        }
+                        restartEnvironment();
+                        restarted = true;
+                        break;
+                    }
+                    catch(EnvironmentFailureException e)
+                    {
+                        LOGGER.warn("Failure whilst trying to restart environment (attempt number "
+                                + "{} of {})", attemptNumber, _environmentRestartRetryLimit, e);
+                        lastException = e;
+                    }
+                    catch (Exception e)
+                    {
+                        LOGGER.error("Fatal failure whilst trying to restart environment", e);
+                        lastException = e;
+                        break;
+                    }
+                    attemptNumber++;
+                }
+
+                if (!restarted)
+                {
+                    LOGGER.error("Failed to restart environment.");
+                    if (lastException != null)
+                    {
+                        handleUncaughtExceptionInExecutorService(lastException);
                     }
                 }
             }, _environmentJobExecutor);
@@ -704,19 +759,15 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
 
         if (_state.get() != State.CLOSING && _state.get() != State.CLOSED)
         {
-            _stateChangeExecutor.submit(new Runnable()
+            _stateChangeExecutor.submit(() ->
             {
-                @Override
-                public void run()
+                try
                 {
-                    try
-                    {
-                        stateChanged(stateChangeEvent);
-                    }
-                    catch (Throwable e)
-                    {
-                        handleUncaughtExceptionInExecutorService(e);
-                    }
+                    stateChanged(stateChangeEvent);
+                }
+                catch (Throwable e)
+                {
+                    handleUncaughtExceptionInExecutorService(e);
                 }
             });
         }
@@ -762,14 +813,10 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
     {
         LOGGER.debug("Submitting a job to set cache size on {} to {}", _prettyGroupNodeName, cacheSize);
 
-        Callable<Void> task = new Callable<Void>()
+        Callable<Void> task = () ->
         {
-            @Override
-            public Void call()
-            {
-                setCacheSizeInternal(cacheSize);
-                return null;
-            }
+            setCacheSizeInternal(cacheSize);
+            return null;
         };
         submitEnvironmentTask(1, task, "setting cache size");
     }
@@ -779,14 +826,10 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
     {
         LOGGER.debug("Submitting a job to set update mutable config on {}", _prettyGroupNodeName);
 
-        Callable<Void> task = new Callable<Void>()
+        Callable<Void> task = () ->
         {
-            @Override
-            public Void call()
-            {
-                EnvironmentUtils.updateMutableConfig(getEnvironment(), PARAMS_SET_BY_DEFAULT, true, object);
-                return null;
-            }
+            EnvironmentUtils.updateMutableConfig(getEnvironment(), PARAMS_SET_BY_DEFAULT, true, object);
+            return null;
         };
         submitEnvironmentTask(5, task, "updating mutable config");
 
@@ -799,14 +842,7 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
         LOGGER.debug("Submitting a job to clean log files on {} ", _prettyGroupNodeName);
         int timeout = 5;
 
-        Callable<Integer> task = new Callable<Integer>()
-        {
-            @Override
-            public Integer call()
-            {
-                return getEnvironment().cleanLog();
-            }
-        };
+        Callable<Integer> task = () -> getEnvironment().cleanLog();
 
 
         Integer fileCount = submitEnvironmentTask(timeout, task, "cleaning log files");
@@ -819,16 +855,12 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
         LOGGER.debug("Submitting a job to perform checkpoint on {} ", _prettyGroupNodeName);
         int timeout = 5;
 
-        Callable<Void> task = new Callable<Void>()
+        Callable<Void> task = () ->
         {
-            @Override
-            public Void call()
-            {
-                CheckpointConfig checkpointConfig = new CheckpointConfig();
-                checkpointConfig.setForce(force);
-                getEnvironment().checkpoint(checkpointConfig);
-                return null;
-            }
+            CheckpointConfig checkpointConfig = new CheckpointConfig();
+            checkpointConfig.setForce(force);
+            getEnvironment().checkpoint(checkpointConfig);
+            return null;
         };
 
         submitEnvironmentTask(timeout, task, "perform checkpoint");
@@ -840,15 +872,8 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
         LOGGER.debug("Submitting a job to get environment statistics on {} ", _prettyGroupNodeName);
         int timeout = 5;
 
-        Callable<Map<String,Map<String,Object>>> task = new Callable<Map<String,Map<String,Object>>>()
-        {
-            @Override
-            public Map<String,Map<String,Object>> call()
-            {
-                return EnvironmentUtils.getEnvironmentStatistics(getEnvironment(), reset);
-
-            }
-        };
+        Callable<Map<String,Map<String,Object>>> task = () ->
+                EnvironmentUtils.getEnvironmentStatistics(getEnvironment(), reset);
 
         return submitEnvironmentTask(timeout, task, "get environment statistics");
     }
@@ -859,14 +884,7 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
         LOGGER.debug("Submitting a job to get transaction statistics on {} ", _prettyGroupNodeName);
         int timeout = 5;
 
-        Callable<Map<String,Object>> task = new Callable<Map<String,Object>>()
-        {
-            @Override
-            public Map<String,Object> call()
-            {
-                return EnvironmentUtils.getTransactionStatistics(getEnvironment(), reset);
-            }
-        };
+        Callable<Map<String,Object>> task = () -> EnvironmentUtils.getTransactionStatistics(getEnvironment(), reset);
 
         return submitEnvironmentTask(timeout, task, "get transaction statistics");
     }
@@ -877,15 +895,7 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
         LOGGER.debug("Submitting a job to get database statistics for {} on {} ", database, _prettyGroupNodeName);
         int timeout = 5;
 
-        Callable<Map<String,Object>> task = new Callable<Map<String,Object>>()
-        {
-            @Override
-            public Map<String, Object> call()
-            {
-
-                return EnvironmentUtils.getDatabaseStatistics(getEnvironment(), database, reset);
-            }
-        };
+        Callable<Map<String,Object>> task = () -> EnvironmentUtils.getDatabaseStatistics(getEnvironment(), database, reset);
 
         return submitEnvironmentTask(timeout, task, "get database statistics for '" + database + "'");
 
@@ -1186,30 +1196,26 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
         // Transfer master contacts the group (using GroupAdmin) to request the mastership change.
         // It needs to be done asynchronously but not on the _environmentJobExecutor, as there is
         // no point delaying transfer master because we are restarting.
-        return _groupChangeExecutor.submit(new Callable<Void>()
+        return _groupChangeExecutor.submit(() ->
         {
-            @Override
-            public Void call() throws Exception
+            try
             {
-                try
+                ReplicationGroupAdmin admin = createReplicationGroupAdmin();
+                String newMaster = admin.transferMaster(Collections.singleton(nodeName),
+                                                        _masterTransferTimeout, TimeUnit.MILLISECONDS, true);
+                if (LOGGER.isDebugEnabled())
                 {
-                    ReplicationGroupAdmin admin = createReplicationGroupAdmin();
-                    String newMaster = admin.transferMaster(Collections.singleton(nodeName),
-                                                            _masterTransferTimeout, TimeUnit.MILLISECONDS, true);
-                    if (LOGGER.isDebugEnabled())
-                    {
-                        LOGGER.debug("The mastership has been transferred to " + newMaster);
-                    }
+                    LOGGER.debug("The mastership has been transferred to " + newMaster);
                 }
-                catch (RuntimeException e)
-                {
-                    String message = "Exception on transferring the mastership to " + _prettyGroupNodeName
-                            + " Master transfer timeout : " + _masterTransferTimeout;
-                    LOGGER.warn(message, e);
-                    throw handleDatabaseException(message, e);
-                }
-                return null;
             }
+            catch (RuntimeException e)
+            {
+                String message = "Exception on transferring the mastership to " + _prettyGroupNodeName
+                        + " Master transfer timeout : " + _masterTransferTimeout;
+                LOGGER.warn(message, e);
+                throw handleDatabaseException(message, e);
+            }
+            return null;
         });
     }
 
@@ -1262,7 +1268,7 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
 
     private ReplicationGroupAdmin createReplicationGroupAdmin()
     {
-        final Set<InetSocketAddress> helpers = new HashSet<InetSocketAddress>();
+        final Set<InetSocketAddress> helpers = new HashSet<>();
         final ReplicationConfig repConfig = getEnvironment().getRepConfig();
 
         helpers.addAll(repConfig.getHelperSockets());
@@ -1547,14 +1553,10 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
     private void createEnvironmentInSeparateThread(final File environmentPathFile, final EnvironmentConfig envConfig,
                                                    final ReplicationConfig replicationConfig, final Runnable postCreationAction)
     {
-        Future<Void> environmentFuture = _environmentJobExecutor.submit(new Callable<Void>()
+        Future<Void> environmentFuture = _environmentJobExecutor.submit(() ->
         {
-            @Override
-            public Void call() throws Exception
-            {
-                createEnvironment(environmentPathFile, envConfig, replicationConfig, postCreationAction);
-                return null;
-            }
+            createEnvironment(environmentPathFile, envConfig, replicationConfig, postCreationAction);
+            return null;
         });
 
         final long setUpTimeOutMillis = extractEnvSetupTimeoutMillis(replicationConfig);
@@ -1696,7 +1698,17 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
             if (!_disableCoalescingCommiter && localTransactionSynchronizationPolicy == LOCAL_TRANSACTION_SYNCHRONIZATION_POLICY)
             {
                 localTransactionSynchronizationPolicy = SyncPolicy.NO_SYNC;
-                _coalescingCommiter = new CoalescingCommiter(_configuration.getGroupName(), this);
+                final int commiterNotifyThreshold = _configuration.getFacadeParameter(
+                        Integer.class,
+                        BDBVirtualHost.QPID_BROKER_BDB_COMMITER_NOTIFY_THRESHOLD,
+                        BDBVirtualHost.DEFAULT_QPID_BROKER_BDB_COMMITER_NOTIFY_THRESHOLD
+                );
+                final long commiterWaitTimeout = _configuration.getFacadeParameter(
+                        Long.class,
+                        BDBVirtualHost.QPID_BROKER_BDB_COMMITER_WAIT_TIMEOUT,
+                        BDBVirtualHost.DEFAULT_QPID_BROKER_BDB_COMMITER_WAIT_TIMEOUT
+                );
+                _coalescingCommiter = new CoalescingCommiter(_configuration.getGroupName(), commiterNotifyThreshold, commiterWaitTimeout,  this);
                 _coalescingCommiter.start();
             }
             _realMessageStoreDurability = new Durability(localTransactionSynchronizationPolicy, remoteTransactionSynchronizationPolicy, replicaAcknowledgmentPolicy);
@@ -1756,7 +1768,7 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
         try
         {
             Map<String, Object> settings = objectMapper.readValue(applicationState, Map.class);
-            return new HashSet<String>((Collection<String>)settings.get(PERMITTED_NODE_LIST));
+            return new HashSet<>((Collection<String>) settings.get(PERMITTED_NODE_LIST));
         }
         catch (Exception e)
         {
@@ -1767,25 +1779,15 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
     public static Collection<String> connectToHelperNodeAndCheckPermittedHosts(final String nodeName, final String hostPort, final String groupName, final String helperNodeName, final String helperHostPort, final int dbPingSocketTimeout)
     {
         ExecutorService executor = null;
-        Future<Collection<String>> future = null;
+        Future<Collection<String>> future;
         try
         {
             executor = Executors.newSingleThreadExecutor(new DaemonThreadFactory(String.format(
                             "PermittedHostsCheck-%s-%s",
                             groupName,
                             nodeName)));
-            future = executor.submit(new Callable<Collection<String>>()
-            {
-                @Override
-                public Collection<String> call() throws Exception
-                {
-                    return getPermittedHostsFromHelper(nodeName,
-                                                       groupName,
-                                                       helperNodeName,
-                                                       helperHostPort,
-                                                       dbPingSocketTimeout);
-                }
-            });
+            future = executor.submit(() ->
+                    getPermittedHostsFromHelper(nodeName, groupName, helperNodeName, helperHostPort, dbPingSocketTimeout));
 
             try
             {
@@ -1938,7 +1940,7 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
 
     private byte[] permittedNodeListToBytes(Set<String> permittedNodeList)
     {
-        HashMap<String, Object> data = new HashMap<String, Object>();
+        HashMap<String, Object> data = new HashMap<>();
         data.put(PERMITTED_NODE_LIST, permittedNodeList);
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         ObjectMapper objectMapper = new ObjectMapper();
@@ -1996,16 +1998,12 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
 
     private void onException(final Exception e)
     {
-        _groupChangeExecutor.submit(new Runnable()
+        _groupChangeExecutor.submit(() ->
         {
-            @Override
-            public void run()
+            ReplicationGroupListener listener = _replicationGroupListener.get();
+            if (listener != null)
             {
-                ReplicationGroupListener listener = _replicationGroupListener.get();
-                if (listener != null)
-                {
-                    listener.onException(e);
-                }
+                listener.onException(e);
             }
         });
     }
@@ -2185,31 +2183,27 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
 
         private Map<ReplicationNode, NodeState> discoverNodeStates(Collection<ReplicationNode> electableNodes)
         {
-            final Map<ReplicationNode, NodeState> nodeStates = new HashMap<ReplicationNode, NodeState>();
-            Map<ReplicationNode, Future<Void>> futureMap = new HashMap<ReplicationNode, Future<Void>>();
+            final Map<ReplicationNode, NodeState> nodeStates = new HashMap<>();
+            Map<ReplicationNode, Future<Void>> futureMap = new HashMap<>();
 
             for (final ReplicationNode node : electableNodes)
             {
                 nodeStates.put(node, null);
 
-                Future<Void> future = _groupChangeExecutor.submit(new Callable<Void>()
+                Future<Void> future = _groupChangeExecutor.submit(() ->
                 {
-                    @Override
-                    public Void call()
+                    NodeState nodeStateObject = null;
+                    try
                     {
-                        NodeState nodeStateObject = null;
-                        try
-                        {
-                            nodeStateObject = getRemoteNodeState(_configuration.getGroupName(), node, _dbPingSocketTimeout);
-                        }
-                        catch (IOException | ServiceConnectFailedException | com.sleepycat.je.rep.utilint.BinaryProtocol.ProtocolException e )
-                        {
-                            // Cannot discover node states. The node state should be treated as UNKNOWN
-                        }
-
-                        nodeStates.put(node, nodeStateObject);
-                        return null;
+                        nodeStateObject = getRemoteNodeState(_configuration.getGroupName(), node, _dbPingSocketTimeout);
                     }
+                    catch (IOException | ServiceConnectFailedException | BinaryProtocol.ProtocolException e )
+                    {
+                        // Cannot discover node states. The node state should be treated as UNKNOWN
+                    }
+
+                    nodeStates.put(node, nodeStateObject);
+                    return null;
                 });
                 futureMap.put(node, future);
             }
@@ -2350,7 +2344,7 @@ public class ReplicatedEnvironmentFacade implements EnvironmentFacade, StateChan
 
     private static class EnvironmentStateHolder implements AppStateMonitor
     {
-        private byte[] _data;
+        private final byte[] _data;
 
         private EnvironmentStateHolder(byte[] data)
         {
