@@ -55,8 +55,8 @@ public class DirectExchangeImpl extends AbstractExchange<DirectExchangeImpl> imp
 
         BindingSet()
         {
-            _unfilteredDestinations = Collections.emptyMap();
-            _filteredDestinations = Collections.emptyMap();
+            _unfilteredDestinations = Map.of();
+            _filteredDestinations = Map.of();
         }
 
         private BindingSet(final Map<MessageDestination, String> unfilteredDestinations,
