@@ -71,6 +71,8 @@ public abstract class ComparisonExpression<T> extends BinaryExpression<T> implem
 
     static class LikeExpression<E> extends UnaryExpression<E> implements BooleanExpression<E>
     {
+        /** Repeated wildcards pattern */
+        private static final Pattern REPEATED_WILDCARDS = Pattern.compile("%{2,}");
 
         private final Pattern likePattern;
 
@@ -78,6 +80,11 @@ public abstract class ComparisonExpression<T> extends BinaryExpression<T> implem
         {
             super(right);
 
+            if (like.contains("%%"))
+            {
+                like = REPEATED_WILDCARDS.matcher(like).replaceAll("%");
+            }
+
             StringBuilder regexp = new StringBuilder(like.length() * 2);
             regexp.append("\\A"); // The beginning of the input
             for (int i = 0; i < like.length(); i++)
