@@ -29,16 +29,11 @@ import java.net.URL;
 import java.security.Principal;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.UUID;
-
-import com.google.common.util.concurrent.FutureCallback;
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
-import com.google.common.util.concurrent.SettableFuture;
+import java.util.concurrent.CompletableFuture;
 
 import org.apache.qpid.server.configuration.IllegalConfigurationException;
 import org.apache.qpid.server.configuration.store.ManagementModeStoreHandler;
@@ -52,7 +47,6 @@ import org.apache.qpid.server.plugin.QpidServiceLoader;
 import org.apache.qpid.server.store.ConfiguredObjectRecord;
 import org.apache.qpid.server.store.ConfiguredObjectRecordConverter;
 import org.apache.qpid.server.store.DurableConfigurationStore;
-import org.apache.qpid.server.store.handler.ConfiguredObjectRecordHandler;
 import org.apache.qpid.server.store.preferences.NoopPreferenceStoreFactoryService;
 import org.apache.qpid.server.store.preferences.PreferenceStore;
 import org.apache.qpid.server.store.preferences.PreferenceStoreAttributes;
@@ -139,7 +133,7 @@ public abstract class AbstractSystemConfig<X extends SystemConfig<X>>
     }
 
     @Override
-    protected ListenableFuture<Void> onClose()
+    protected CompletableFuture<Void> onClose()
     {
         final TaskExecutor taskExecutor = getTaskExecutor();
         try
@@ -163,7 +157,7 @@ public abstract class AbstractSystemConfig<X extends SystemConfig<X>>
                 taskExecutor.stopImmediately();
             }
         }
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
     }
 
     @Override
@@ -225,36 +219,29 @@ public abstract class AbstractSystemConfig<X extends SystemConfig<X>>
 
 
     @StateTransition(currentState = State.ACTIVE, desiredState = State.STOPPED)
-    protected ListenableFuture<Void> doStop()
+    protected CompletableFuture<Void> doStop()
     {
-        return doAfter(getContainer().closeAsync(), new Runnable()
+        final Container<?> container = getContainer();
+        if (container == null)
         {
-            @Override
-            public void run()
-            {
-                _configurationStore.closeConfigurationStore();
-                AbstractSystemConfig.super.setState(State.STOPPED);
-            }
-        });
-
+            return CompletableFuture.completedFuture(null);
+        }
+        return container.closeAsync().thenRunAsync(() ->
+        {
+            _configurationStore.closeConfigurationStore();
+            AbstractSystemConfig.super.setState(State.STOPPED);
+        }, getTaskExecutor());
     }
 
 
     @StateTransition(currentState = { State.UNINITIALIZED, State.STOPPED }, desiredState = State.ACTIVE)
-    protected ListenableFuture<Void> activate()
+    protected CompletableFuture<Void> activate()
     {
-        return doAfter(makeActive(), new Runnable()
-        {
-            @Override
-            public void run()
-            {
-                AbstractSystemConfig.super.setState(State.ACTIVE);
-            }
-        });
+        return makeActive().thenRunAsync(() -> AbstractSystemConfig.super.setState(State.ACTIVE), getTaskExecutor());
     }
 
 
-    protected ListenableFuture<Void> makeActive()
+    protected CompletableFuture<Void> makeActive()
     {
 
         final EventLogger eventLogger = _eventLogger;
@@ -266,32 +253,28 @@ public abstract class AbstractSystemConfig<X extends SystemConfig<X>>
             final Container<?> container = initiateStoreAndRecovery();
 
             container.setEventLogger(startupLogger);
-            final SettableFuture<Void> returnVal = SettableFuture.create();
-            addFutureCallback(container.openAsync(), new FutureCallback()
-                                {
-                                    @Override
-                                    public void onSuccess(final Object result)
-                                    {
-                                        State state = container.getState();
-                                        if (state == State.ACTIVE)
-                                        {
-                                            startupLogger.message(BrokerMessages.READY());
-                                            container.setEventLogger(eventLogger);
-                                            returnVal.set(null);
-                                        }
-                                        else
-                                        {
-                                            returnVal.setException(new ServerScopedRuntimeException("Broker failed reach ACTIVE state (state is " + state + ")"));
-                                        }
-                                    }
-
-                                    @Override
-                                    public void onFailure(final Throwable t)
-                                    {
-                                        returnVal.setException(t);
-                                    }
-                                }, getTaskExecutor()
-                               );
+            final CompletableFuture<Void> returnVal = new CompletableFuture<>();
+            container.openAsync().whenCompleteAsync((result, error) ->
+            {
+                if (error != null)
+                {
+                    returnVal.completeExceptionally(error);
+                }
+                else
+                {
+                    State state = container.getState();
+                    if (state == State.ACTIVE)
+                    {
+                        startupLogger.message(BrokerMessages.READY());
+                        container.setEventLogger(eventLogger);
+                        returnVal.complete(null);
+                    }
+                    else
+                    {
+                        returnVal.completeExceptionally(new ServerScopedRuntimeException("Broker failed reach ACTIVE state (state is " + state + ")"));
+                    }
+                }
+            }, getTaskExecutor());
 
             return returnVal;
         }
@@ -312,14 +295,7 @@ public abstract class AbstractSystemConfig<X extends SystemConfig<X>>
         store.upgradeStoreStructure();
         final List<ConfiguredObjectRecord> records = new ArrayList<>();
 
-        boolean isNew = store.openConfigurationStore(new ConfiguredObjectRecordHandler()
-        {
-            @Override
-            public void handle(final ConfiguredObjectRecord record)
-            {
-                records.add(record);
-            }
-        }, initialRecords);
+        boolean isNew = store.openConfigurationStore(records::add, initialRecords);
 
         String containerTypeName = getDefaultContainerType();
         for(ConfiguredObjectRecord record : records)
@@ -353,7 +329,7 @@ public abstract class AbstractSystemConfig<X extends SystemConfig<X>>
 
 
     @StateTransition(currentState = State.UNINITIALIZED, desiredState = State.QUIESCED)
-    protected ListenableFuture<Void> startQuiesced()
+    protected CompletableFuture<Void> startQuiesced()
     {
         final EventLogger startupLogger = initiateStartupLogging();
 
@@ -362,7 +338,7 @@ public abstract class AbstractSystemConfig<X extends SystemConfig<X>>
             final Container<?> container = initiateStoreAndRecovery();
 
             container.setEventLogger(startupLogger);
-            return Futures.immediateFuture(null);
+            return CompletableFuture.completedFuture(null);
         }
         catch (IOException e)
         {
@@ -502,7 +478,7 @@ public abstract class AbstractSystemConfig<X extends SystemConfig<X>>
         if (preferenceStoreAttributes == null)
         {
             preferenceStoreType = NoopPreferenceStoreFactoryService.TYPE;
-            attributes = Collections.emptyMap();
+            attributes = Map.of();
         }
         else
         {
