@@ -28,9 +28,20 @@ public interface BrokerLogger<X extends BrokerLogger<X>> extends ConfiguredObjec
 
     void stopLogging();
 
-    @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.COUNT, label = "Errors", metricName = "errors_count")
+    @ManagedStatistic(statisticType = StatisticType.CUMULATIVE,
+            units = StatisticUnit.COUNT,
+            label = "Errors",
+            metricName = "errors_count",
+            resettable = true)
     long getErrorCount();
 
-    @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.COUNT, label = "Warnings", metricName = "warnings_count")
+    @ManagedStatistic(statisticType = StatisticType.CUMULATIVE,
+            units = StatisticUnit.COUNT,
+            label = "Warnings",
+            metricName = "warnings_count",
+            resettable = true)
     long getWarnCount();
+
+    @ManagedOperation(description = "Resets broker logger statistics", changesConfiguredObjectState = true)
+    void resetStatistics();
 }
