@@ -31,12 +31,9 @@ import org.apache.qpid.server.filter.JMSSelectorFilter;
 import org.apache.qpid.server.filter.SelectorParsingException;
 import org.apache.qpid.server.filter.selector.ParseException;
 import org.apache.qpid.server.filter.selector.TokenMgrError;
-import org.apache.qpid.server.logging.LogMessage;
-import org.apache.qpid.server.logging.messages.QueueMessages;
 import org.apache.qpid.server.message.ServerMessage;
 import org.apache.qpid.server.message.ServerMessageMutator;
 import org.apache.qpid.server.message.ServerMessageMutatorFactory;
-import org.apache.qpid.server.model.LifetimePolicy;
 import org.apache.qpid.server.model.ManagedAttributeField;
 import org.apache.qpid.server.model.ManagedObjectFactoryConstructor;
 import org.apache.qpid.server.store.MessageEnqueueRecord;
