@@ -54,19 +54,17 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
 import javax.net.ssl.CertPathTrustManagerParameters;
 import javax.net.ssl.TrustManager;
 import javax.net.ssl.TrustManagerFactory;
 import javax.net.ssl.X509TrustManager;
 
-import com.google.common.collect.Sets;
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
-
 import org.apache.qpid.server.logging.Outcome;
 import org.apache.qpid.server.transport.network.security.ssl.SSLUtil;
 import org.slf4j.Logger;
@@ -165,10 +163,10 @@ public abstract class AbstractTrustStore<X extends AbstractTrustStore<X>>
     }
 
     @Override
-    protected ListenableFuture<Void> onClose()
+    protected CompletableFuture<Void> onClose()
     {
         onCloseOrDelete();
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
     }
 
     @Override
@@ -244,7 +242,7 @@ public abstract class AbstractTrustStore<X extends AbstractTrustStore<X>>
     }
 
     @Override
-    protected ListenableFuture<Void> onDelete()
+    protected CompletableFuture<Void> onDelete()
     {
         onCloseOrDelete();
         return super.onDelete();
@@ -288,7 +286,7 @@ public abstract class AbstractTrustStore<X extends AbstractTrustStore<X>>
             long timeToExpiry = cert.getNotAfter().getTime() - currentTime;
             int days = Math.max(0,(int)(timeToExpiry / (ONE_DAY)));
 
-            getEventLogger().message(TrustStoreMessages.EXPIRING(getName(), String.valueOf(days), cert.getSubjectDN().toString()));
+            getEventLogger().message(TrustStoreMessages.EXPIRING(getName(), String.valueOf(days), cert.getSubjectX500Principal().getName()));
         }
         catch(CertificateNotYetValidException e)
         {
@@ -301,7 +299,7 @@ public abstract class AbstractTrustStore<X extends AbstractTrustStore<X>>
     {
         if (isTrustAnchorValidityEnforced())
         {
-            final Set<Certificate> trustManagerCerts = Sets.newHashSet(getCertificates());
+            final Set<Certificate> trustManagerCerts = Stream.of(getCertificates()).collect(Collectors.toSet());
             final Set<TrustAnchor> trustAnchors = new HashSet<>();
             final Set<Certificate> otherCerts = new HashSet<>();
             for (Certificate certs : trustManagerCerts)
@@ -413,7 +411,7 @@ public abstract class AbstractTrustStore<X extends AbstractTrustStore<X>>
      */
     private Collection<? extends CRL> getCRLs(String crlUrl)
     {
-        Collection<? extends CRL> crls = Collections.emptyList();
+        Collection<? extends CRL> crls = List.of();
         if (crlUrl != null)
         {
             try (InputStream is = getUrlFromString(crlUrl).openStream())
