@@ -25,9 +25,8 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.CompletableFuture;
 
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -97,14 +96,14 @@ public abstract class AbstractAuthenticationManager<T extends AbstractAuthentica
 
 
     @StateTransition( currentState = State.UNINITIALIZED, desiredState = State.QUIESCED )
-    protected ListenableFuture<Void> startQuiesced()
+    protected CompletableFuture<Void> startQuiesced()
     {
         setState(State.QUIESCED);
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
     }
 
     @StateTransition( currentState = { State.UNINITIALIZED, State.QUIESCED, State.QUIESCED }, desiredState = State.ACTIVE )
-    protected ListenableFuture<Void> activate()
+    protected CompletableFuture<Void> activate()
     {
         try
         {
@@ -122,7 +121,7 @@ public abstract class AbstractAuthenticationManager<T extends AbstractAuthentica
                 throw e;
             }
         }
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
     }
 
     @Override
@@ -153,48 +152,29 @@ public abstract class AbstractAuthenticationManager<T extends AbstractAuthentica
     protected void logCreated(final Map<String, Object> attributes,
                               final Outcome outcome)
     {
-        if (outcome == Outcome.SUCCESS)
-        {
-            _eventLogger.message(AuthenticationProviderMessages.CREATE(getName()));
-        }
-        else
-        {
-            super.logCreated(attributes, outcome);
-        }
+        _eventLogger.message(AuthenticationProviderMessages.CREATE(getName(),
+                                                                   String.valueOf(outcome),
+                                                                   attributesAsString(attributes)));
     }
 
     @Override
     protected void logRecovered(final Outcome outcome)
     {
-        if (outcome == Outcome.SUCCESS)
-        {
-            _eventLogger.message(AuthenticationProviderMessages.CREATE(getName()));
-        }
-        else
-        {
-            super.logRecovered(outcome);
-        }
+        _eventLogger.message(AuthenticationProviderMessages.OPEN(getName(), String.valueOf(outcome)));
     }
 
     @Override
     protected void logDeleted(final Outcome outcome)
     {
-        if (outcome == Outcome.SUCCESS)
-        {
-            getEventLogger().message(AuthenticationProviderMessages.DELETE(getName()));
-        }
-        else
-        {
-            super.logDeleted(outcome);
-        }
+        _eventLogger.message(AuthenticationProviderMessages.DELETE(getName(), String.valueOf(outcome)));
     }
 
     @Override
     protected void logUpdated(final Map<String, Object> attributes, final Outcome outcome)
     {
-        getEventLogger().message(AuthenticationProviderMessages.UPDATE(getName(),
-                                                                       String.valueOf(outcome),
-                                                                       attributesAsString(attributes)));
+        _eventLogger.message(AuthenticationProviderMessages.UPDATE(getName(),
+                                                                   String.valueOf(outcome),
+                                                                   attributesAsString(attributes)));
     }
 
 }
