@@ -23,8 +23,7 @@ package org.apache.qpid.server.security.auth.manager;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
-
-import com.google.common.util.concurrent.ListenableFuture;
+import java.util.concurrent.CompletableFuture;
 
 import org.apache.qpid.server.logging.Outcome;
 import org.apache.qpid.server.logging.messages.AuthenticationProviderMessages;
@@ -36,6 +35,8 @@ import org.apache.qpid.server.model.ManagedObject;
 import org.apache.qpid.server.model.ManagedObjectFactoryConstructor;
 import org.apache.qpid.server.model.State;
 import org.apache.qpid.server.model.User;
+import org.apache.qpid.server.util.ClearableCharSequence;
+import org.apache.qpid.server.util.Strings;
 
 @ManagedObject( category = false, type = ManagedUser.MANAGED_USER_TYPE)
 class ManagedUser extends AbstractConfiguredObject<ManagedUser> implements User<ManagedUser>
@@ -75,7 +76,7 @@ class ManagedUser extends AbstractConfiguredObject<ManagedUser> implements User<
     }
 
     @Override
-    protected ListenableFuture<Void> onDelete()
+    protected CompletableFuture<Void> onDelete()
     {
         _authenticationManager.getUserMap().remove(getName());
         return super.onDelete();
@@ -119,8 +120,11 @@ class ManagedUser extends AbstractConfiguredObject<ManagedUser> implements User<
     @Override
     protected void logCreated(final Map<String, Object> attributes, final Outcome outcome)
     {
-        ((Container<?>) _authenticationManager.getParent()).getEventLogger()
-            .message(UserMessages.CREATE(getName(), outcome.name(), String.valueOf(getActualAttributes())));
+        try (ClearableCharSequence charSequence = Strings.toCharSequence(String.valueOf(getActualAttributes())))
+        {
+            ((Container<?>) _authenticationManager.getParent()).getEventLogger()
+                    .message(UserMessages.CREATE(getName(), outcome.name(), charSequence));
+        }
     }
 
     @Override
@@ -133,7 +137,10 @@ class ManagedUser extends AbstractConfiguredObject<ManagedUser> implements User<
     @Override
     protected void logUpdated(final Map<String, Object> attributes, final Outcome outcome)
     {
-        ((Container<?>) _authenticationManager.getParent()).getEventLogger()
-            .message(UserMessages.UPDATE(getName(), outcome.name(), String.valueOf(getActualAttributes())));
+        try (ClearableCharSequence charSequence = Strings.toCharSequence(String.valueOf(getActualAttributes())))
+        {
+            ((Container<?>) _authenticationManager.getParent()).getEventLogger()
+                    .message(UserMessages.UPDATE(getName(), outcome.name(), charSequence));
+        }
     }
 }
