@@ -20,14 +20,10 @@
  */
 package org.apache.qpid.server.security.group.cloudfoundry;
 
-import static org.apache.qpid.server.configuration.CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_BLACK_LIST;
 import static org.apache.qpid.server.configuration.CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST;
 import static org.apache.qpid.server.configuration.CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST;
-import static org.apache.qpid.server.configuration.CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_WHITE_LIST;
-import static org.apache.qpid.server.configuration.CommonProperties.QPID_SECURITY_TLS_PROTOCOL_BLACK_LIST;
 import static org.apache.qpid.server.configuration.CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST;
 import static org.apache.qpid.server.configuration.CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST;
-import static org.apache.qpid.server.configuration.CommonProperties.QPID_SECURITY_TLS_PROTOCOL_WHITE_LIST;
 import static org.apache.qpid.server.util.ParameterizedTypes.LIST_OF_STRINGS;
 
 import java.io.IOException;
@@ -44,11 +40,11 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.CompletableFuture;
 
 import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.databind.ObjectMapper;
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -91,10 +87,10 @@ public class CloudFoundryDashboardManagementGroupProviderImpl extends AbstractCo
     @ManagedAttributeField
     private Map<String, String> _serviceToManagementGroupMapping;
 
-    private List<String> _tlsProtocolWhiteList;
-    private List<String> _tlsProtocolBlackList;
-    private List<String> _tlsCipherSuiteWhiteList;
-    private List<String> _tlsCipherSuiteBlackList;
+    private List<String> _tlsProtocolAllowList;
+    private List<String> _tlsProtocolDenyList;
+    private List<String> _tlsCipherSuiteAllowList;
+    private List<String> _tlsCipherSuiteDenyList;
     private int _connectTimeout;
     private int _readTimeout;
 
@@ -108,10 +104,10 @@ public class CloudFoundryDashboardManagementGroupProviderImpl extends AbstractCo
     public void onOpen()
     {
         super.onOpen();
-        _tlsProtocolWhiteList = getContextValue(List.class, LIST_OF_STRINGS, QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST, QPID_SECURITY_TLS_PROTOCOL_WHITE_LIST);
-        _tlsProtocolBlackList = getContextValue(List.class, LIST_OF_STRINGS, QPID_SECURITY_TLS_PROTOCOL_DENY_LIST, QPID_SECURITY_TLS_PROTOCOL_BLACK_LIST);
-        _tlsCipherSuiteWhiteList = getContextValue(List.class, LIST_OF_STRINGS, QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST, QPID_SECURITY_TLS_CIPHER_SUITE_WHITE_LIST);
-        _tlsCipherSuiteBlackList = getContextValue(List.class, LIST_OF_STRINGS, QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST, QPID_SECURITY_TLS_CIPHER_SUITE_BLACK_LIST);
+        _tlsProtocolAllowList = getContextValue(List.class, LIST_OF_STRINGS, QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST);
+        _tlsProtocolDenyList = getContextValue(List.class, LIST_OF_STRINGS, QPID_SECURITY_TLS_PROTOCOL_DENY_LIST);
+        _tlsCipherSuiteAllowList = getContextValue(List.class, LIST_OF_STRINGS, QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST);
+        _tlsCipherSuiteDenyList = getContextValue(List.class, LIST_OF_STRINGS, QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST);
         _connectTimeout = getContextValue(Integer.class, QPID_GROUPPROVIDER_CLOUDFOUNDRY_CONNECT_TIMEOUT);
         _readTimeout = getContextValue(Integer.class, QPID_GROUPPROVIDER_CLOUDFOUNDRY_READ_TIMEOUT);
     }
@@ -211,10 +207,10 @@ public class CloudFoundryDashboardManagementGroupProviderImpl extends AbstractCo
                     throw new ServerScopedRuntimeException("Cannot initialise TLS", e);
                 }
             }
-            connectionBuilder.setTlsProtocolWhiteList(_tlsProtocolWhiteList)
-                             .setTlsProtocolBlackList(_tlsProtocolBlackList)
-                             .setTlsCipherSuiteWhiteList(_tlsCipherSuiteWhiteList)
-                             .setTlsCipherSuiteBlackList(_tlsCipherSuiteBlackList);
+            connectionBuilder.setTlsProtocolAllowList(_tlsProtocolAllowList)
+                             .setTlsProtocolDenyList(_tlsProtocolDenyList)
+                             .setTlsCipherSuiteAllowList(_tlsCipherSuiteAllowList)
+                             .setTlsCipherSuiteDenyList(_tlsCipherSuiteDenyList);
 
             LOGGER.debug("About to call CloudFoundryDashboardManagementEndpoint '{}'", cloudFoundryEndpoint);
             connection = connectionBuilder.build();
@@ -267,10 +263,10 @@ public class CloudFoundryDashboardManagementGroupProviderImpl extends AbstractCo
     }
 
     @StateTransition( currentState = { State.UNINITIALIZED, State.QUIESCED, State.ERRORED }, desiredState = State.ACTIVE )
-    private ListenableFuture<Void> activate()
+    private CompletableFuture<Void> activate()
     {
         setState(State.ACTIVE);
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
     }
 
     @Override
@@ -291,53 +287,28 @@ public class CloudFoundryDashboardManagementGroupProviderImpl extends AbstractCo
         return _serviceToManagementGroupMapping;
     }
 
-    @Override
-    public List<String> getTlsProtocolWhiteList()
-    {
-        return _tlsProtocolWhiteList;
-    }
-
-    @Override
-    public List<String> getTlsProtocolBlackList()
-    {
-        return _tlsProtocolBlackList;
-    }
-
-    @Override
-    public List<String> getTlsCipherSuiteWhiteList()
-    {
-        return _tlsCipherSuiteWhiteList;
-    }
-
-    @Override
-    public List<String> getTlsCipherSuiteBlackList()
-    {
-        return _tlsCipherSuiteBlackList;
-    }
-
     @Override
     public List<String> getTlsProtocolAllowList()
     {
-        return getTlsProtocolWhiteList();
+        return _tlsProtocolAllowList;
     }
 
     @Override
     public List<String> getTlsProtocolDenyList()
     {
-        return getTlsProtocolBlackList();
+        return _tlsProtocolDenyList;
     }
 
     @Override
     public List<String> getTlsCipherSuiteAllowList()
     {
-        return getTlsCipherSuiteWhiteList();
+        return _tlsCipherSuiteAllowList;
     }
 
     @Override
     public List<String> getTlsCipherSuiteDenyList()
     {
-        return getTlsCipherSuiteBlackList();
+        return _tlsCipherSuiteDenyList;
     }
 
-
 }
