@@ -25,11 +25,10 @@ import java.security.AccessControlContext;
 import java.security.Principal;
 import java.util.Collection;
 import java.util.Iterator;
+import java.util.concurrent.CompletableFuture;
 
 import javax.security.auth.Subject;
 
-import com.google.common.util.concurrent.ListenableFuture;
-
 import org.apache.qpid.server.logging.EventLoggerProvider;
 import org.apache.qpid.server.model.Broker;
 import org.apache.qpid.server.model.Connection;
@@ -39,7 +38,6 @@ import org.apache.qpid.server.txn.LocalTransaction;
 import org.apache.qpid.server.txn.ServerTransaction;
 import org.apache.qpid.server.util.Action;
 import org.apache.qpid.server.util.Deletable;
-import org.apache.qpid.server.virtualhost.ConnectionPrincipalStatistics;
 
 public interface AMQPConnection<C extends AMQPConnection<C>>
         extends Connection<C>, Deletable<C>, EventLoggerProvider
@@ -124,7 +122,7 @@ public interface AMQPConnection<C extends AMQPConnection<C>>
     void sendConnectionCloseAsync(CloseReason reason, String description);
 
     boolean isIOThread();
-    ListenableFuture<Void> doOnIOThreadAsync(final Runnable task);
+    CompletableFuture<Void> doOnIOThreadAsync(final Runnable task);
 
     void checkAuthorizedMessagePrincipal(String messageUserId);
 
@@ -147,11 +145,4 @@ public interface AMQPConnection<C extends AMQPConnection<C>>
 
     @Override
     AmqpPort<?> getPort();
-
-    void registered(ConnectionPrincipalStatistics connectionPrincipalStatistics);
-
-    int getAuthenticatedPrincipalConnectionCount();
-
-    int getAuthenticatedPrincipalConnectionFrequency();
-
 }
