@@ -28,6 +28,7 @@ import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
 import java.util.ListIterator;
+import java.util.concurrent.atomic.AtomicInteger;
 
 import javax.net.ssl.SNIHostName;
 import javax.net.ssl.SSLEngine;
@@ -43,7 +44,6 @@ import org.slf4j.LoggerFactory;
 import org.apache.qpid.server.bytebuffer.QpidByteBuffer;
 import org.apache.qpid.server.model.port.AmqpPort;
 import org.apache.qpid.server.transport.network.security.ssl.SSLUtil;
-import org.apache.qpid.server.util.ConnectionScopedRuntimeException;
 import org.apache.qpid.server.util.ServerScopedRuntimeException;
 
 public class NonBlockingConnectionTLSDelegate implements NonBlockingConnectionDelegate
@@ -62,8 +62,10 @@ public class NonBlockingConnectionTLSDelegate implements NonBlockingConnectionDe
     private QpidByteBuffer _netInputBuffer;
     private QpidByteBuffer _netOutputBuffer;
     private QpidByteBuffer _applicationBuffer;
-    private final boolean _ignoreInvalidSni;
-
+    private final AtomicInteger _loopingCounter = new AtomicInteger(0);
+    private final boolean _enableDiagnosisOfSslEngineLooping;
+    private final long _diagnosisOfSslEngineLoopingWarnThreshold;
+    private final long _diagnosisOfSslEngineLoopingBreakThreshold;
 
     public NonBlockingConnectionTLSDelegate(NonBlockingConnection parent, AmqpPort port)
     {
@@ -81,7 +83,9 @@ public class NonBlockingConnectionTLSDelegate implements NonBlockingConnectionDe
         _netInputBuffer = QpidByteBuffer.allocateDirect(_networkBufferSize);
         _applicationBuffer = QpidByteBuffer.allocateDirect(_networkBufferSize);
         _netOutputBuffer = QpidByteBuffer.allocateDirect(_networkBufferSize);
-        _ignoreInvalidSni = port.isIgnoreInvalidSni();
+        _enableDiagnosisOfSslEngineLooping = port.getContextValue(Boolean.class, AmqpPort.PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING);
+        _diagnosisOfSslEngineLoopingWarnThreshold = port.getContextValue(Integer.class, AmqpPort.PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING_WARN_THRESHOLD);
+        _diagnosisOfSslEngineLoopingBreakThreshold = port.getContextValue(Integer.class, AmqpPort.PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING_BREAK_THRESHOLD);
     }
 
     @Override
@@ -161,20 +165,10 @@ public class NonBlockingConnectionTLSDelegate implements NonBlockingConnectionDe
 
     private SNIHostName getSNIHostName(final QpidByteBuffer buffer)
     {
-        try
+        final String name = SSLUtil.getServerNameFromTLSClientHello(buffer);
+        if (name != null)
         {
-            final String name = SSLUtil.getServerNameFromTLSClientHello(buffer);
-            if (name != null)
-            {
-                return SSLUtil.createSNIHostName(name);
-            }
-        }
-        catch (ConnectionScopedRuntimeException e)
-        {
-            if (!_ignoreInvalidSni)
-            {
-                throw e;
-            }
+            return SSLUtil.createSNIHostName(name);
         }
         return null;
     }
@@ -300,7 +294,27 @@ public class NonBlockingConnectionTLSDelegate implements NonBlockingConnectionDe
                     _encryptedOutput.add(_netOutputBuffer);
                     _netOutputBuffer = QpidByteBuffer.allocateDirect(_networkBufferSize);
                 }
-
+                // SSLEngine looping circuit breaker
+                if (_enableDiagnosisOfSslEngineLooping)
+                {
+                    _loopingCounter.incrementAndGet();
+                    if (_loopingCounter.get() > _diagnosisOfSslEngineLoopingWarnThreshold)
+                    {
+                        LOGGER.warn("SSLEngine looping detected, _status: {}, _sslEngine.isOutboundDone(): {}, _sslEngine.isInboundDone(): {}, "
+                                        + "_sslEngine.getPeerHost(): {}, _sslEngine.getPeerPort(): {}",
+                                "[ Status = " + _status.getStatus() + ", HandshakeStatus = " + _status.getHandshakeStatus()
+                                        + ", bytesConsumed = " + _status.bytesConsumed() + ", bytesProduced = " + _status.bytesProduced() + " ]",
+                                _sslEngine.isOutboundDone(),
+                                _sslEngine.isInboundDone(),
+                                _sslEngine.getPeerHost(),
+                                _sslEngine.getPeerPort()
+                        );
+                    }
+                    if (_loopingCounter.get() > _diagnosisOfSslEngineLoopingBreakThreshold)
+                    {
+                        throw new SSLException("SSLEngine looping detected, executing circuit breaker");
+                    }
+                }
             }
             else
             {
@@ -310,6 +324,11 @@ public class NonBlockingConnectionTLSDelegate implements NonBlockingConnectionDe
         }
         while(encrypted && _sslEngine.getHandshakeStatus() != SSLEngineResult.HandshakeStatus.NEED_UNWRAP);
 
+        if (_enableDiagnosisOfSslEngineLooping && encrypted)
+        {
+            _loopingCounter.set(0);
+        }
+
         if(_netOutputBuffer.position() != 0)
         {
             final QpidByteBuffer outputBuffer = _netOutputBuffer;
@@ -387,9 +406,9 @@ public class NonBlockingConnectionTLSDelegate implements NonBlockingConnectionDe
     {
         SSLEngine sslEngine = port.getSSLContext().createSSLEngine();
         sslEngine.setUseClientMode(false);
-        SSLUtil.updateEnabledTlsProtocols(sslEngine, port.getTlsProtocolWhiteList(), port.getTlsProtocolBlackList());
-        SSLUtil.updateEnabledCipherSuites(sslEngine, port.getTlsCipherSuiteWhiteList(), port.getTlsCipherSuiteBlackList());
-        if(port.getTlsCipherSuiteWhiteList() != null && !port.getTlsCipherSuiteWhiteList().isEmpty())
+        SSLUtil.updateEnabledTlsProtocols(sslEngine, port.getTlsProtocolAllowList(), port.getTlsProtocolDenyList());
+        SSLUtil.updateEnabledCipherSuites(sslEngine, port.getTlsCipherSuiteAllowList(), port.getTlsCipherSuiteDenyList());
+        if(port.getTlsCipherSuiteAllowList() != null && !port.getTlsCipherSuiteAllowList().isEmpty())
         {
             SSLParameters sslParameters = sslEngine.getSSLParameters();
             sslParameters.setUseCipherSuitesOrder(true);
