@@ -20,11 +20,11 @@
  */
 package org.apache.qpid.server.virtualhost;
 
-import com.google.common.util.concurrent.ListenableFuture;
+import java.util.concurrent.CompletableFuture;
 
 public interface MessageStoreRecoverer
 {
-    ListenableFuture<Void> recover(QueueManagingVirtualHost<?> virtualHost);
+    CompletableFuture<Void> recover(QueueManagingVirtualHost<?> virtualHost);
 
     /**
      * Cancels any in-progress message store recovery.  If message store recovery has already
