@@ -20,12 +20,13 @@
  */
 package org.apache.qpid.server.security.encryption;
 
-import static org.apache.qpid.server.security.encryption.AESKeyFileEncrypterFactoryTest.createSecretKey;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.instanceOf;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.MatcherAssert.assertThat;
 
+import java.security.SecureRandom;
+
 import javax.crypto.spec.SecretKeySpec;
 
 import org.junit.jupiter.api.BeforeEach;
@@ -56,4 +57,11 @@ public class AESGCMKeyFileEncrypterFactoryTest extends UnitTestBase
         final ConfigurationSecretEncrypter encrypter = _factory.createEncrypter(secretKey);
         assertThat(encrypter, is(instanceOf(AESGCMKeyFileEncrypter.class)));
     }
+
+    private SecretKeySpec createSecretKey()
+    {
+        final byte[] keyData = new byte[32];
+        new SecureRandom().nextBytes(keyData);
+        return new SecretKeySpec(keyData, "AES");
+    }
 }
