@@ -40,6 +40,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Random;
 import java.util.Set;
+import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.TimeUnit;
 
 import javax.crypto.SecretKeyFactory;
@@ -48,7 +49,6 @@ import javax.crypto.spec.SecretKeySpec;
 
 import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.ObjectMapper;
-import com.google.common.util.concurrent.SettableFuture;
 
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
@@ -188,10 +188,10 @@ public class AESGCMKeyFileEncrypterTest extends UnitTestBase
     @Test
     public void testChangeOfEncryptionToGCM() throws Exception
     {
-        createBrokerAndAuthenticationProviderWithEncrypterPassword(AESKeyFileEncrypterFactory.TYPE);
+        createBrokerAndAuthenticationProviderWithEncrypterPassword(AESGCMKeyFileEncrypterFactory.TYPE);
         final String aesEncryptedPassword = getEncryptedPasswordFromConfig();
         final SecretKeySpec aesSecretKey = new SecretKeySpec(getBrokerSecretKey(), "AES");
-        final AESKeyFileEncrypter cbcEncrypter = new AESKeyFileEncrypter(aesSecretKey);
+        final AESGCMKeyFileEncrypter cbcEncrypter = new AESGCMKeyFileEncrypter(aesSecretKey);
         final String aesDecryptedPassword = cbcEncrypter.decrypt(aesEncryptedPassword);
         assertEquals(SECRET, aesDecryptedPassword, "Decrypted text doesnt match original");
         _broker.setAttributes(Map.of(
@@ -231,9 +231,9 @@ public class AESGCMKeyFileEncrypterTest extends UnitTestBase
         final String gcmDecryptedPassword = gcmEncrypter.decrypt(gcmEncryptedPassword);
         assertEquals(SECRET, gcmDecryptedPassword, "Decrypted text doesnt match original");
         _broker.setAttributes(Map.of(
-                Broker.CONFIDENTIAL_CONFIGURATION_ENCRYPTION_PROVIDER, "AESKeyFile"));
+                Broker.CONFIDENTIAL_CONFIGURATION_ENCRYPTION_PROVIDER, "AESGCMKeyFile"));
         final String cbcEncryptedPassword = getEncryptedPasswordFromConfig();
-        final AESKeyFileEncrypter cbcEncrypter = new AESKeyFileEncrypter(aesSecretKey);
+        final AESGCMKeyFileEncrypter cbcEncrypter = new AESGCMKeyFileEncrypter(aesSecretKey);
         final String cbcDecryptedPassword = cbcEncrypter.decrypt(cbcEncryptedPassword);
         assertEquals(SECRET, cbcDecryptedPassword, "Decrypted text doesnt match original");
     }
@@ -280,13 +280,13 @@ public class AESGCMKeyFileEncrypterTest extends UnitTestBase
                 SystemConfig.TYPE, JsonSystemConfigImpl.SYSTEM_CONFIG_TYPE,
                 SystemConfig.STARTUP_LOGGED_TO_SYSTEM_OUT, Boolean.FALSE,
                 SystemConfig.CONTEXT, context);
-        final SettableFuture<SystemConfig<?>> configFuture = SettableFuture.create();
+        final CompletableFuture<SystemConfig<?>> configFuture = new CompletableFuture<>();
         _systemLauncher = new SystemLauncher(new SystemLauncherListener.DefaultSystemLauncherListener()
         {
             @Override
             public void onContainerResolve(final SystemConfig<?> systemConfig)
             {
-                configFuture.set(systemConfig);
+                configFuture.complete(systemConfig);
             }
         });
         _systemLauncher.startup(attributes);
