@@ -20,15 +20,15 @@
  */
 package org.apache.qpid.server.util;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.IOException;
 import java.nio.ByteBuffer;
-import java.util.Arrays;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.test.utils.UnitTestBase;
 
@@ -37,7 +37,7 @@ public class ByteBufferInputStreamTest extends UnitTestBase
     private final byte[] _data = {2, 1, 5, 3, 4};
     private ByteBufferInputStream _inputStream;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception
     {
         _inputStream = new ByteBufferInputStream(ByteBuffer.wrap(_data));
@@ -48,55 +48,55 @@ public class ByteBufferInputStreamTest extends UnitTestBase
     {
         for (int i = 0; i < _data.length; i++)
         {
-            assertEquals("Unexpected byte at position " + i, (long) _data[i], (long) _inputStream.read());
+            assertEquals(_data[i], (long) _inputStream.read(), "Unexpected byte at position " + i);
         }
-        assertEquals("EOF not reached", (long) -1, (long) _inputStream.read());
+        assertEquals(-1, (long) _inputStream.read(), "EOF not reached");
     }
 
     @Test
     public void testReadByteArray() throws IOException
     {
-        byte[] readBytes = new byte[_data.length];
+        final byte[] readBytes = new byte[_data.length];
         int length = _inputStream.read(readBytes, 0, 2);
 
-        byte[] expected = new byte[_data.length];
+        final byte[] expected = new byte[_data.length];
         System.arraycopy(_data, 0, expected, 0, 2);
 
-        assertTrue("Unexpected data", Arrays.equals(expected, readBytes));
-        assertEquals("Unexpected length", (long) 2, (long) length);
+        assertArrayEquals(expected, readBytes, "Unexpected data");
+        assertEquals(2, (long) length, "Unexpected length");
 
         length = _inputStream.read(readBytes, 2, 3);
 
-        assertTrue("Unexpected data", Arrays.equals(_data, readBytes));
-        assertEquals("Unexpected length", (long) 3, (long) length);
+        assertArrayEquals(_data, readBytes, "Unexpected data");
+        assertEquals(3, (long) length, "Unexpected length");
 
         length = _inputStream.read(readBytes);
-        assertEquals("EOF not reached", (long) -1, (long) length);
+        assertEquals(-1, (long) length, "EOF not reached");
     }
 
     @Test
     public void testSkip() throws IOException
     {
         _inputStream.skip(3);
-        byte[] readBytes = new byte[_data.length - 3];
-        int length = _inputStream.read(readBytes);
+        final byte[] readBytes = new byte[_data.length - 3];
+        final int length = _inputStream.read(readBytes);
 
-        byte[] expected = new byte[_data.length - 3];
+        final byte[] expected = new byte[_data.length - 3];
         System.arraycopy(_data, 3, expected, 0, _data.length - 3);
 
-        assertTrue("Unexpected data", Arrays.equals(expected, readBytes));
-        assertEquals("Unexpected length", (long) (_data.length - 3), (long) length);
+        assertArrayEquals(expected, readBytes, "Unexpected data");
+        assertEquals(_data.length - 3, (long) length, "Unexpected length");
     }
 
     @Test
     public void testAvailable() throws IOException
     {
         int available = _inputStream.available();
-        assertEquals("Unexpected number of available bytes", (long) _data.length, (long) available);
-        byte[] readBytes = new byte[_data.length];
+        assertEquals(_data.length, (long) available, "Unexpected number of available bytes");
+        final byte[] readBytes = new byte[_data.length];
         _inputStream.read(readBytes);
         available = _inputStream.available();
-        assertEquals("Unexpected number of available bytes", (long) 0, (long) available);
+        assertEquals(0, (long) available, "Unexpected number of available bytes");
     }
 
     @Test
@@ -105,20 +105,19 @@ public class ByteBufferInputStreamTest extends UnitTestBase
         _inputStream.mark(0);
         byte[] readBytes = new byte[_data.length];
         int length = _inputStream.read(readBytes);
-        assertEquals("Unexpected length", (long) _data.length, (long) length);
-        assertEquals("Unexpected number of available bytes", (long) 0, (long) _inputStream.available());
+        assertEquals(_data.length, (long) length, "Unexpected length");
+        assertEquals(0, (long) _inputStream.available(), "Unexpected number of available bytes");
 
         _inputStream.reset();
         readBytes = new byte[_data.length];
         length = _inputStream.read(readBytes);
-        assertEquals("Unexpected length", (long) _data.length, (long) length);
-        assertEquals("Unexpected number of available bytes", (long) 0, (long) _inputStream.available());
+        assertEquals(_data.length, (long) length, "Unexpected length");
+        assertEquals(0, (long) _inputStream.available(), "Unexpected number of available bytes");
     }
 
     @Test
-    public void testMarkSupported() throws IOException
+    public void testMarkSupported()
     {
-        assertTrue("Unexpected mark supported", _inputStream.markSupported());
+        assertTrue(_inputStream.markSupported(), "Unexpected mark supported");
     }
-
 }
