@@ -20,7 +20,7 @@
  */
 package org.apache.qpid.server.virtualhost;
 
-import static org.junit.Assert.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.argThat;
 import static org.mockito.ArgumentMatchers.eq;
@@ -33,13 +33,13 @@ import static org.mockito.Mockito.when;
 
 import java.util.UUID;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+
 import org.mockito.ArgumentMatcher;
 
 import org.apache.qpid.server.logging.EventLogger;
 import org.apache.qpid.server.message.EnqueueableMessage;
-import org.apache.qpid.server.message.MessageInstance;
 import org.apache.qpid.server.message.ServerMessage;
 import org.apache.qpid.server.model.Queue;
 import org.apache.qpid.server.queue.QueueEntry;
@@ -62,17 +62,16 @@ import org.apache.qpid.server.txn.Xid;
 import org.apache.qpid.server.util.Action;
 import org.apache.qpid.test.utils.UnitTestBase;
 
+@SuppressWarnings({"rawtypes", "unchecked"})
 public class SynchronousMessageStoreRecovererTest extends UnitTestBase
 {
     private QueueManagingVirtualHost<?> _virtualHost;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception
     {
-
         _virtualHost = mock(QueueManagingVirtualHost.class);
         when(_virtualHost.getEventLogger()).thenReturn(new EventLogger());
-
     }
 
     @SuppressWarnings("unchecked")
@@ -80,20 +79,19 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
     public void testRecoveryOfSingleMessageOnSingleQueue()
     {
         final Queue<?> queue = createRegisteredMockQueue();
-
         final long messageId = 1;
         final StoredMessage<StorableMessageMetaData> storedMessage = createMockStoredMessage(messageId);
 
-        MessageStore store = new NullMessageStore()
+        final MessageStore store = new NullMessageStore()
         {
             @Override
-            public void visitMessages(MessageHandler handler) throws StoreException
+            public void visitMessages(final MessageHandler handler) throws StoreException
             {
                 handler.handle(storedMessage);
             }
 
             @Override
-            public void visitMessageInstances(MessageInstanceHandler handler) throws StoreException
+            public void visitMessageInstances(final MessageInstanceHandler handler) throws StoreException
             {
                 handler.handle(new TestMessageEnqueueRecord(queue.getId(), messageId));
             }
@@ -101,11 +99,10 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
 
         when(_virtualHost.getMessageStore()).thenReturn(store);
 
-        SynchronousMessageStoreRecoverer
-                recoverer = new SynchronousMessageStoreRecoverer();
+        final SynchronousMessageStoreRecoverer recoverer = new SynchronousMessageStoreRecoverer();
         recoverer.recover(_virtualHost);
 
-        ServerMessage<?> message = storedMessage.getMetaData().getType().createMessage(storedMessage);
+        final ServerMessage<?> message = storedMessage.getMetaData().getType().createMessage(storedMessage);
         verify(queue, times(1)).recover(eq(message), any(MessageEnqueueRecord.class));
     }
 
@@ -114,20 +111,19 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
     public void testRecoveryOfMessageInstanceForNonExistingMessage()
     {
         final Queue<?> queue = createRegisteredMockQueue();
-
         final long messageId = 1;
         final Transaction transaction = mock(Transaction.class);
 
-        MessageStore store = new NullMessageStore()
+        final MessageStore store = new NullMessageStore()
         {
             @Override
-            public void visitMessages(MessageHandler handler) throws StoreException
+            public void visitMessages(final MessageHandler handler) throws StoreException
             {
                 // no message to visit
             }
 
             @Override
-            public void visitMessageInstances(MessageInstanceHandler handler) throws StoreException
+            public void visitMessageInstances(final MessageInstanceHandler handler) throws StoreException
             {
                 handler.handle(new TestMessageEnqueueRecord(queue.getId(), messageId));
             }
@@ -141,8 +137,7 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
 
         when(_virtualHost.getMessageStore()).thenReturn(store);
 
-        SynchronousMessageStoreRecoverer
-                recoverer = new SynchronousMessageStoreRecoverer();
+        final SynchronousMessageStoreRecoverer recoverer = new SynchronousMessageStoreRecoverer();
         recoverer.recover(_virtualHost);
 
         verify(queue, never()).enqueue(any(ServerMessage.class), any(Action.class), any(MessageEnqueueRecord.class));
@@ -153,21 +148,21 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
     @Test
     public void testRecoveryOfMessageInstanceForNonExistingQueue()
     {
-        final UUID queueId = UUID.randomUUID();
+        final UUID queueId = randomUUID();
         final Transaction transaction = mock(Transaction.class);
         final long messageId = 1;
         final StoredMessage<StorableMessageMetaData> storedMessage = createMockStoredMessage(messageId);
 
-        MessageStore store = new NullMessageStore()
+        final MessageStore store = new NullMessageStore()
         {
             @Override
-            public void visitMessages(MessageHandler handler) throws StoreException
+            public void visitMessages(final MessageHandler handler) throws StoreException
             {
                 handler.handle(storedMessage);
             }
 
             @Override
-            public void visitMessageInstances(MessageInstanceHandler handler) throws StoreException
+            public void visitMessageInstances(final MessageInstanceHandler handler) throws StoreException
             {
                 handler.handle(new TestMessageEnqueueRecord(queueId, messageId));
             }
@@ -181,8 +176,7 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
 
         when(_virtualHost.getMessageStore()).thenReturn(store);
 
-        SynchronousMessageStoreRecoverer
-                recoverer = new SynchronousMessageStoreRecoverer();
+        final SynchronousMessageStoreRecoverer recoverer = new SynchronousMessageStoreRecoverer();
         recoverer.recover(_virtualHost);
 
         verify(transaction).dequeueMessage(argThat(new MessageEnqueueRecordMatcher(queueId, messageId)));
@@ -192,20 +186,19 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
     @Test
     public void testRecoveryDeletesOrphanMessages()
     {
-
         final long messageId = 1;
         final StoredMessage<StorableMessageMetaData> storedMessage = createMockStoredMessage(messageId);
 
-        MessageStore store = new NullMessageStore()
+        final MessageStore store = new NullMessageStore()
         {
             @Override
-            public void visitMessages(MessageHandler handler) throws StoreException
+            public void visitMessages(final MessageHandler handler) throws StoreException
             {
                 handler.handle(storedMessage);
             }
 
             @Override
-            public void visitMessageInstances(MessageInstanceHandler handler) throws StoreException
+            public void visitMessageInstances(final MessageInstanceHandler handler) throws StoreException
             {
                 // No messages instances
             }
@@ -213,8 +206,7 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
 
         when(_virtualHost.getMessageStore()).thenReturn(store);
 
-        SynchronousMessageStoreRecoverer
-                recoverer = new SynchronousMessageStoreRecoverer();
+        final SynchronousMessageStoreRecoverer recoverer = new SynchronousMessageStoreRecoverer();
         recoverer.recover(_virtualHost);
 
         verify(storedMessage, times(1)).remove();
@@ -224,15 +216,13 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
     @Test
     public void testRecoveryOfSingleEnqueueWithDistributedTransaction()
     {
-        Queue<?> queue = createRegisteredMockQueue();
-
+        final Queue<?> queue = createRegisteredMockQueue();
         final Transaction transaction = mock(Transaction.class);
-
         final StoredMessage<StorableMessageMetaData> storedMessage = createMockStoredMessage(1);
-        long messageId = storedMessage.getMessageNumber();
+        final long messageId = storedMessage.getMessageNumber();
 
-        EnqueueableMessage enqueueableMessage = createMockEnqueueableMessage(messageId, storedMessage);
-        EnqueueRecord enqueueRecord = createMockRecord(queue, enqueueableMessage);
+        final EnqueueableMessage<?> enqueueableMessage = createMockEnqueueableMessage(messageId, storedMessage);
+        final EnqueueRecord enqueueRecord = createMockRecord(queue, enqueueableMessage);
 
         final long format = 1;
         final byte[] globalId = new byte[] {0};
@@ -240,22 +230,22 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
         final EnqueueRecord[] enqueues = { enqueueRecord };
         final Transaction.DequeueRecord[] dequeues = {};
 
-        MessageStore store = new NullMessageStore()
+        final MessageStore store = new NullMessageStore()
         {
             @Override
-            public void visitMessages(MessageHandler handler) throws StoreException
+            public void visitMessages(final MessageHandler handler) throws StoreException
             {
                 handler.handle(storedMessage);
             }
 
             @Override
-            public void visitMessageInstances(MessageInstanceHandler handler) throws StoreException
+            public void visitMessageInstances(final MessageInstanceHandler handler) throws StoreException
             {
                 // No messages instances
             }
 
             @Override
-            public void visitDistributedTransactions(DistributedTransactionHandler handler) throws StoreException
+            public void visitDistributedTransactions(final DistributedTransactionHandler handler) throws StoreException
             {
                 handler.handle(new Transaction.StoredXidRecord()
                 {
@@ -286,20 +276,19 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
             }
         };
 
-        DtxRegistry dtxRegistry = new DtxRegistry(_virtualHost);
+        final DtxRegistry dtxRegistry = new DtxRegistry(_virtualHost);
 
         when(_virtualHost.getMessageStore()).thenReturn(store);
         when(_virtualHost.getDtxRegistry()).thenReturn(dtxRegistry);
 
-        SynchronousMessageStoreRecoverer
-                recoverer = new SynchronousMessageStoreRecoverer();
+        final SynchronousMessageStoreRecoverer recoverer = new SynchronousMessageStoreRecoverer();
         recoverer.recover(_virtualHost);
 
-        DtxBranch branch = dtxRegistry.getBranch(new Xid(format, globalId, branchId));
-        assertNotNull("Expected dtx branch to be created", branch);
+        final DtxBranch branch = dtxRegistry.getBranch(new Xid(format, globalId, branchId));
+        assertNotNull(branch, "Expected dtx branch to be created");
         branch.commit();
 
-        ServerMessage<?> message = storedMessage.getMetaData().getType().createMessage(storedMessage);
+        final ServerMessage<?> message = storedMessage.getMetaData().getType().createMessage(storedMessage);
         verify(queue, times(1)).enqueue(eq(message), isNull(), isNull());
         verify(transaction).commitTran();
     }
@@ -307,37 +296,34 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
     @Test
     public void testRecoveryOfSingleDequeueWithDistributedTransaction()
     {
-        final UUID queueId = UUID.randomUUID();
+        final UUID queueId = randomUUID();
         final Queue<?> queue = createRegisteredMockQueue(queueId);
-
-
         final Transaction transaction = mock(Transaction.class);
         final StoredMessage<StorableMessageMetaData> storedMessage = createMockStoredMessage(1);
         final long messageId = storedMessage.getMessageNumber();
 
-        Transaction.DequeueRecord dequeueRecord = createMockDequeueRecord(queueId, messageId);
+        final Transaction.DequeueRecord dequeueRecord = createMockDequeueRecord(queueId, messageId);
 
-        QueueEntry queueEntry = mock(QueueEntry.class);
+        final QueueEntry queueEntry = mock(QueueEntry.class);
         when(queueEntry.acquire()).thenReturn(true);
         when(queue.getMessageOnTheQueue(messageId)).thenReturn(queueEntry);
 
-
         final long format = 1;
         final byte[] globalId = new byte[] {0};
         final byte[] branchId = new byte[] {0};
         final EnqueueRecord[] enqueues = {};
         final Transaction.DequeueRecord[] dequeues = { dequeueRecord };
 
-        MessageStore store = new NullMessageStore()
+        final MessageStore store = new NullMessageStore()
         {
             @Override
-            public void visitMessages(MessageHandler handler) throws StoreException
+            public void visitMessages(final MessageHandler handler) throws StoreException
             {
                 handler.handle(storedMessage);
             }
 
             @Override
-            public void visitMessageInstances(MessageInstanceHandler handler) throws StoreException
+            public void visitMessageInstances(final MessageInstanceHandler handler) throws StoreException
             {
                 // We need the message to be enqueued onto the queue so that later the distributed transaction
                 // can dequeue it.
@@ -345,7 +331,7 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
             }
 
             @Override
-            public void visitDistributedTransactions(DistributedTransactionHandler handler) throws StoreException
+            public void visitDistributedTransactions(final DistributedTransactionHandler handler) throws StoreException
             {
                 handler.handle(new Transaction.StoredXidRecord()
                 {
@@ -376,47 +362,44 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
             }
         };
 
-        DtxRegistry dtxRegistry = new DtxRegistry(_virtualHost);
+        final DtxRegistry dtxRegistry = new DtxRegistry(_virtualHost);
 
         when(_virtualHost.getMessageStore()).thenReturn(store);
         when(_virtualHost.getDtxRegistry()).thenReturn(dtxRegistry);
 
-        SynchronousMessageStoreRecoverer
-                recoverer = new SynchronousMessageStoreRecoverer();
+        final SynchronousMessageStoreRecoverer recoverer = new SynchronousMessageStoreRecoverer();
         recoverer.recover(_virtualHost);
 
-        DtxBranch branch = dtxRegistry.getBranch(new Xid(format, globalId, branchId));
-        assertNotNull("Expected dtx branch to be created", branch);
+        final DtxBranch branch = dtxRegistry.getBranch(new Xid(format, globalId, branchId));
+        assertNotNull(branch, "Expected dtx branch to be created");
         branch.commit();
 
         verify(queueEntry, times(1)).delete();
         verify(transaction).commitTran();
     }
 
-
-    protected EnqueueRecord createMockRecord(Queue<?> queue, EnqueueableMessage enqueueableMessage)
+    protected EnqueueRecord createMockRecord(final Queue<?> queue, final EnqueueableMessage<?> enqueueableMessage)
     {
-        EnqueueRecord enqueueRecord = mock(EnqueueRecord.class);
+        final EnqueueRecord enqueueRecord = mock(EnqueueRecord.class);
         when(enqueueRecord.getMessage()).thenReturn(enqueueableMessage);
         when(enqueueRecord.getResource()).thenReturn(queue);
         return enqueueRecord;
     }
 
-
-    protected Transaction.DequeueRecord createMockDequeueRecord(UUID queueId, long messageNumber)
+    protected Transaction.DequeueRecord createMockDequeueRecord(final UUID queueId, final long messageNumber)
     {
-        Transaction.DequeueRecord dequeueRecord = mock(Transaction.DequeueRecord.class);
-        MessageEnqueueRecord enqueueRecord = mock(MessageEnqueueRecord.class);
+        final Transaction.DequeueRecord dequeueRecord = mock(Transaction.DequeueRecord.class);
+        final MessageEnqueueRecord enqueueRecord = mock(MessageEnqueueRecord.class);
         when(enqueueRecord.getMessageNumber()).thenReturn(messageNumber);
         when(enqueueRecord.getQueueId()).thenReturn(queueId);
         when(dequeueRecord.getEnqueueRecord()).thenReturn(enqueueRecord);
         return dequeueRecord;
     }
 
-    protected EnqueueableMessage createMockEnqueueableMessage(long messageId,
-            final StoredMessage<StorableMessageMetaData> storedMessage)
+    protected EnqueueableMessage<?> createMockEnqueueableMessage(final long messageId,
+                                                                 final StoredMessage<StorableMessageMetaData> storedMessage)
     {
-        EnqueueableMessage enqueueableMessage = mock(EnqueueableMessage.class);
+        final EnqueueableMessage enqueueableMessage = mock(EnqueueableMessage.class);
         when(enqueueableMessage.getMessageNumber()).thenReturn(messageId);
         when(enqueueableMessage.getStoredMessage()).thenReturn(storedMessage);
         return enqueueableMessage;
@@ -424,9 +407,7 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
 
     private StoredMessage<StorableMessageMetaData> createMockStoredMessage(final long messageId)
     {
-        TestMessageMetaData metaData = new TestMessageMetaData(messageId, 0);
-
-        @SuppressWarnings("unchecked")
+        final TestMessageMetaData metaData = new TestMessageMetaData(messageId, 0);
         final StoredMessage<StorableMessageMetaData> storedMessage = mock(StoredMessage.class);
         when(storedMessage.getMessageNumber()).thenReturn(messageId);
         when(storedMessage.getMetaData()).thenReturn(metaData);
@@ -435,12 +416,12 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
 
     private Queue<?> createRegisteredMockQueue()
     {
-        return createRegisteredMockQueue(UUID.randomUUID());
+        return createRegisteredMockQueue(randomUUID());
     }
 
     private Queue<?> createRegisteredMockQueue(UUID queueId)
     {
-        Queue queue = mock(Queue.class);
+        final Queue queue = mock(Queue.class);
         when(queue.getMessageDurability()).thenReturn(MessageDurability.DEFAULT);
         when(queue.getId()).thenReturn(queueId);
         when(queue.getName()).thenReturn("test-queue");
@@ -449,20 +430,19 @@ public class SynchronousMessageStoreRecovererTest extends UnitTestBase
         return queue;
     }
 
-
     private static final class MessageEnqueueRecordMatcher implements ArgumentMatcher<MessageEnqueueRecord>
     {
         private final long _messageId;
         private final UUID _queueId;
 
-        private MessageEnqueueRecordMatcher(UUID queueId, long messageId)
+        private MessageEnqueueRecordMatcher(final UUID queueId, final long messageId)
         {
             _messageId = messageId;
             _queueId = queueId;
         }
 
         @Override
-        public boolean matches(MessageEnqueueRecord argument)
+        public boolean matches(final MessageEnqueueRecord argument)
         {
             return argument.getMessageNumber() == _messageId
                     && argument.getQueueId().equals(_queueId);
