@@ -288,18 +288,18 @@ public class GenerateLogMessages
         Set<String> messageKeys = new TreeSet<>(messages.keySet());
 
         //Create the return map
-        HashMap<String, Object> messageTypeData = new HashMap<String, Object>();
+        HashMap<String, Object> messageTypeData = new HashMap<>();
         // Store the name to give to this Class <name>Messages.java
         messageTypeData.put("name", messsageName);
 
         // Prepare the list of log messages
-        List<HashMap> logMessageList = new LinkedList<HashMap>();
+        List<HashMap> logMessageList = new LinkedList<>();
         messageTypeData.put("list", logMessageList);
 
         //Process each of the properties
         for(String message : messageKeys)
         {
-            HashMap<String, Object> logEntryData = new HashMap<String, Object>();
+            HashMap<String, Object> logEntryData = new HashMap<>();
 
             // Process the log message if it matches the specified key e.g.'BRK_'
             if (!message.equals("package"))
@@ -472,14 +472,14 @@ public class GenerateLogMessages
                 // The parameter type
                 String type;
 
-                //Be default all types are Strings
+                // By default all types are CharSequence
                 if (typeIndex == -1 || typeIndexEnd == -1)
                 {
-                    type = "String";
+                    type = "CharSequence";
                 }
                 else
                 {
-                    //Check string ',....}' for existence of number
+                    // Check string ',....}' for existence of number
                     // to identify this parameter as an integer
                     // This allows for a style value to be present
                     // Only check the text inside the braces '{}'
