@@ -17,7 +17,7 @@
  * under the License.
  *
  */
-package org.apache.qpid.server.protocol.v0_8;
+package org.apache.qpid.server.protocol.v0_10;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
@@ -31,11 +31,9 @@ import java.io.ObjectOutputStream;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 
-import com.google.common.collect.Lists;
-import com.google.common.io.ByteStreams;
-
 import org.junit.jupiter.api.Test;
 
 import org.mockito.ArgumentCaptor;
@@ -54,9 +52,9 @@ import org.apache.qpid.server.typedmessage.mimecontentconverter.ListToJmsStreamM
 import org.apache.qpid.server.typedmessage.mimecontentconverter.MapToJmsMapMessage;
 import org.apache.qpid.test.utils.UnitTestBase;
 
-class MessageConverter_Internal_to_0_8Test extends UnitTestBase
+class MessageConverter_Internal_to_0_10Test extends UnitTestBase
 {
-    private final MessageConverter_Internal_to_v0_8 _converter = new MessageConverter_Internal_to_v0_8();
+    private final MessageConverter_Internal_to_v0_10 _converter = new MessageConverter_Internal_to_v0_10();
     private final StoredMessage<InternalMessageMetaData> _handle = mock(StoredMessage.class);
     private final AMQMessageHeader _amqpHeader = mock(AMQMessageHeader.class);
 
@@ -86,7 +84,7 @@ class MessageConverter_Internal_to_0_8Test extends UnitTestBase
     @Test
     void listMessageWithMimeType() throws Exception
     {
-        final ArrayList<?> content = Lists.newArrayList("testItem", 37.5, 42);
+        final ArrayList<?> content = new ArrayList<>(List.of("testItem", 37.5, 42));
         final ListToJmsStreamMessage listToJmsStreamMessage = new ListToJmsStreamMessage();
         final byte[] expectedContent = listToJmsStreamMessage.toMimeContent(content);
         doTest(content, "foo/bar", expectedContent, listToJmsStreamMessage.getMimeType());
@@ -95,7 +93,7 @@ class MessageConverter_Internal_to_0_8Test extends UnitTestBase
     @Test
     void listMessageWithoutMimeType() throws Exception
     {
-        final ArrayList<?> content = Lists.newArrayList("testItem", 37.5, 42);
+        final ArrayList<?> content = new ArrayList<>(List.of("testItem", 37.5, 42));
         final ListToJmsStreamMessage listToJmsStreamMessage = new ListToJmsStreamMessage();
         final byte[] expectedContent = listToJmsStreamMessage.toMimeContent(content);
         doTest(content, null, expectedContent, listToJmsStreamMessage.getMimeType());
@@ -104,7 +102,7 @@ class MessageConverter_Internal_to_0_8Test extends UnitTestBase
     @Test
     void listMessageWithoutMimeTypeWithNonJmsContent() throws Exception
     {
-        final ArrayList<?> content = Lists.newArrayList("testItem", 37.5, 42, Lists.newArrayList());
+        final ArrayList<?> content = new ArrayList<>(List.of("testItem", 37.5, 42, List.of()));
         final ListToAmqpListConverter listToAmqpListConverter = new ListToAmqpListConverter();
         final byte[] expectedContent = listToAmqpListConverter.toMimeContent(content);
         doTest(content, null, expectedContent, listToAmqpListConverter.getMimeType());
@@ -113,7 +111,7 @@ class MessageConverter_Internal_to_0_8Test extends UnitTestBase
     @Test
     void listMessageWithoutMimeTypeWithNonConvertibleItem() throws Exception
     {
-        final ArrayList<?> content = Lists.newArrayList(new MySerializable());
+        final ArrayList<?> content = new ArrayList<>(List.of(new MySerializable()));
         final InternalMessage sourceMessage = getAmqMessage(content, null);
         doTest(content, null, getObjectStreamMessageBytes(content), "application/java-object-stream");
     }
@@ -246,8 +244,8 @@ class MessageConverter_Internal_to_0_8Test extends UnitTestBase
         final ArgumentCaptor<Integer> offsetCaptor = ArgumentCaptor.forClass(Integer.class);
         final ArgumentCaptor<Integer> sizeCaptor = ArgumentCaptor.forClass(Integer.class);
 
-        when(_handle.getContent(offsetCaptor.capture(), sizeCaptor.capture())).then(invocation ->
-                combined.view(offsetCaptor.getValue(), sizeCaptor.getValue()));
+        when(_handle.getContent(offsetCaptor.capture(), sizeCaptor.capture()))
+                .then(invocation -> combined.view(offsetCaptor.getValue(), sizeCaptor.getValue()));
     }
 
     private void doTest(final Serializable messageBytes,
@@ -256,7 +254,7 @@ class MessageConverter_Internal_to_0_8Test extends UnitTestBase
                         final String expectedContentType) throws Exception
     {
         final InternalMessage sourceMessage = getAmqMessage(messageBytes, mimeType);
-        final AMQMessage convertedMessage = _converter.convert(sourceMessage, mock(NamedAddressSpace.class));
+        final MessageTransferMessage convertedMessage = _converter.convert(sourceMessage, mock(NamedAddressSpace.class));
         final QpidByteBuffer content = convertedMessage.getContent();
 
         assertArrayEquals(expectedContent != null ? expectedContent : new byte[0], getBytes(content), "Unexpected content");
@@ -268,7 +266,7 @@ class MessageConverter_Internal_to_0_8Test extends UnitTestBase
         try (final ByteArrayOutputStream bos = new ByteArrayOutputStream();
              final InputStream contentInputStream = content.asInputStream())
         {
-            ByteStreams.copy(contentInputStream, bos);
+            contentInputStream.transferTo(bos);
             content.dispose();
             return bos.toByteArray();
         }
