@@ -21,16 +21,15 @@
 package org.apache.qpid.server.logging.logback;
 
 import static org.apache.qpid.server.util.LoggerTestHelper.assertLoggedEvent;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
 import java.util.Collection;
-import java.util.HashMap;
 import java.util.Map;
 
 import ch.qos.logback.classic.Level;
@@ -38,9 +37,11 @@ import ch.qos.logback.classic.spi.ILoggingEvent;
 import ch.qos.logback.core.Appender;
 import ch.qos.logback.core.Context;
 import ch.qos.logback.core.read.ListAppender;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -55,6 +56,7 @@ import org.apache.qpid.server.model.Model;
 import org.apache.qpid.server.model.State;
 import org.apache.qpid.test.utils.UnitTestBase;
 
+@SuppressWarnings({"rawtypes", "unchecked"})
 public class BrokerLoggerTest extends UnitTestBase
 {
     public static final String APPENDER_NAME = "test";
@@ -64,18 +66,16 @@ public class BrokerLoggerTest extends UnitTestBase
     private TaskExecutor _taskExecutor;
     private Broker _broker;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception
     {
-
         _taskExecutor = new TaskExecutorImpl();
         _taskExecutor.start();
 
         _loggerAppender = new ListAppender<>();
         _loggerAppender.setName(APPENDER_NAME);
 
-
-        Model model = BrokerModel.getInstance();
+        final Model model = BrokerModel.getInstance();
 
         _broker = mock(Broker.class);
         when(_broker.getCategoryClass()).thenReturn(Broker.class);
@@ -84,12 +84,11 @@ public class BrokerLoggerTest extends UnitTestBase
         when(_broker.getChildExecutor()).thenReturn(_taskExecutor);
         doReturn(Broker.class).when(_broker).getCategoryClass();
 
-        Map<String, Object> attributes = new HashMap<>();
-        attributes.put("name", APPENDER_NAME);
+        final Map<String, Object> attributes = Map.of("name", APPENDER_NAME);
         _brokerLogger = new AbstractBrokerLogger(attributes, _broker)
         {
             @Override
-            public Appender<ILoggingEvent> createAppenderInstance(Context context)
+            public Appender<ILoggingEvent> createAppenderInstance(final Context context)
             {
                 return _loggerAppender;
             }
@@ -97,42 +96,31 @@ public class BrokerLoggerTest extends UnitTestBase
         _brokerLogger.open();
     }
 
-
-
-    @After
-    public void tearDown() throws Exception
+    @AfterEach
+    public void tearDown()
     {
-        try
-        {
-            if (_brokerLogger != null)
-            {
-                _brokerLogger.delete();
-            }
-            _taskExecutor.stopImmediately();
-        }
-        finally
-        {
-        }
+        _brokerLogger.delete();
+        _taskExecutor.stopImmediately();
     }
 
     @Test
     public void testAddNewLogInclusionRule()
     {
-        Map<String, Object> attributes = createBrokerNameAndLevelLogInclusionRuleAttributes("org.apache.qpid", LogLevel.INFO);
+        final Map<String, Object> attributes = createBrokerNameAndLevelLogInclusionRuleAttributes("org.apache.qpid", LogLevel.INFO);
 
-        Collection<BrokerLogInclusionRule> rulesBefore = _brokerLogger.getChildren(BrokerLogInclusionRule.class);
-        assertEquals("Unexpected number of rules before creation", (long) 0, (long) rulesBefore.size());
+        final Collection<BrokerLogInclusionRule> rulesBefore = _brokerLogger.getChildren(BrokerLogInclusionRule.class);
+        assertEquals(0, (long) rulesBefore.size(), "Unexpected number of rules before creation");
 
-        BrokerLogInclusionRule<?> createdRule = _brokerLogger.createChild(BrokerLogInclusionRule.class, attributes);
-        assertEquals("Unexpected rule name", "test", createdRule.getName());
+        final BrokerLogInclusionRule<?> createdRule = _brokerLogger.createChild(BrokerLogInclusionRule.class, attributes);
+        assertEquals("test", createdRule.getName(), "Unexpected rule name");
 
-        Collection<BrokerLogInclusionRule> rulesAfter = _brokerLogger.getChildren(BrokerLogInclusionRule.class);
-        assertEquals("Unexpected number of rules after creation", (long) 1, (long) rulesAfter.size());
+        final Collection<BrokerLogInclusionRule> rulesAfter = _brokerLogger.getChildren(BrokerLogInclusionRule.class);
+        assertEquals(1, (long) rulesAfter.size(), "Unexpected number of rules after creation");
 
-        BrokerLogInclusionRule filter = rulesAfter.iterator().next();
-        assertEquals("Unexpected rule", createdRule, filter);
+        final BrokerLogInclusionRule filter = rulesAfter.iterator().next();
+        assertEquals(createdRule, filter, "Unexpected rule");
 
-        Logger logger = LoggerFactory.getLogger("org.apache.qpid");
+        final Logger logger = LoggerFactory.getLogger("org.apache.qpid");
 
         logger.debug("Test2");
         logger.info("Test3");
@@ -143,9 +131,9 @@ public class BrokerLoggerTest extends UnitTestBase
     @Test
     public void testRemoveExistingRule()
     {
-        Map<String, Object> attributes = createBrokerNameAndLevelLogInclusionRuleAttributes("org.apache.qpid", LogLevel.INFO);
-        BrokerLogInclusionRule<?> createdRule = _brokerLogger.createChild(BrokerLogInclusionRule.class, attributes);
-        Logger logger = LoggerFactory.getLogger("org.apache.qpid");
+        final Map<String, Object> attributes = createBrokerNameAndLevelLogInclusionRuleAttributes("org.apache.qpid", LogLevel.INFO);
+        final BrokerLogInclusionRule<?> createdRule = _brokerLogger.createChild(BrokerLogInclusionRule.class, attributes);
+        final Logger logger = LoggerFactory.getLogger("org.apache.qpid");
 
         logger.info("Test1");
         assertLoggedEvent(_loggerAppender, true, "Test1", logger.getName(), Level.INFO);
@@ -159,52 +147,51 @@ public class BrokerLoggerTest extends UnitTestBase
     @Test
     public void testDeleteLogger()
     {
-        ch.qos.logback.classic.Logger rootLogger =
+        final ch.qos.logback.classic.Logger rootLogger =
                 (ch.qos.logback.classic.Logger) LoggerFactory.getLogger(Logger.ROOT_LOGGER_NAME);
-        assertNotNull("Appender not found when it should have been created",
-                             rootLogger.getAppender(_brokerLogger.getName()));
+        assertNotNull(rootLogger.getAppender(_brokerLogger.getName()),
+                "Appender not found when it should have been created");
 
         _brokerLogger.delete();
-        assertEquals("Unexpected state after deletion", State.DELETED, _brokerLogger.getState());
-        assertNull("Appender found when it should have been deleted",
-                          rootLogger.getAppender(_brokerLogger.getName()));
+        assertEquals(State.DELETED, _brokerLogger.getState(), "Unexpected state after deletion");
+        assertNull(rootLogger.getAppender(_brokerLogger.getName()),
+                "Appender found when it should have been deleted");
     }
 
     @Test
     public void testBrokerMemoryLoggerGetLogEntries()
     {
-        Map<String, Object> attributes = new HashMap<>();
-        attributes.put(BrokerMemoryLogger.NAME, getTestName());
-        attributes.put(ConfiguredObject.TYPE, BrokerMemoryLogger.TYPE);
-        BrokerMemoryLogger logger = new BrokerMemoryLoggerImplFactory().createInstance(attributes, _broker);
+        final Map<String, Object> attributes = Map.of(BrokerMemoryLogger.NAME, getTestName(),
+                ConfiguredObject.TYPE, BrokerMemoryLogger.TYPE);
+        final BrokerMemoryLogger logger = new BrokerMemoryLoggerImplFactory().createInstance(attributes, _broker);
         try
         {
             logger.open();
 
-            Map<String, Object> filterAttributes = createBrokerNameAndLevelLogInclusionRuleAttributes("", LogLevel.ALL);
+            final Map<String, Object> filterAttributes = createBrokerNameAndLevelLogInclusionRuleAttributes("", LogLevel.ALL);
             logger.createChild(BrokerLogInclusionRule.class, filterAttributes);
 
-            Logger messageLogger = LoggerFactory.getLogger("org.apache.qpid.test");
+            final Logger messageLogger = LoggerFactory.getLogger("org.apache.qpid.test");
             messageLogger.debug("test message 1");
-            Collection<LogRecord> logRecords = logger.getLogEntries(0);
+            final Collection<LogRecord> logRecords = logger.getLogEntries(0);
 
-            LogRecord foundRecord = findLogRecord("test message 1", logRecords);
+            final LogRecord foundRecord = findLogRecord("test message 1", logRecords);
 
-            assertNotNull("Record is not found", foundRecord);
+            assertNotNull(foundRecord, "Record is not found");
 
             messageLogger.debug("test message 2");
 
-            Collection<LogRecord> logRecords2 = logger.getLogEntries(foundRecord.getId());
-            for (LogRecord record: logRecords2)
+            final Collection<LogRecord> logRecords2 = logger.getLogEntries(foundRecord.getId());
+            for (final LogRecord record: logRecords2)
             {
-                assertTrue("Record id " + record.getId() + " is below " + foundRecord.getId(),
-                                  record.getId() > foundRecord.getId());
+                assertTrue(record.getId() > foundRecord.getId(),
+                        "Record id " + record.getId() + " is below " + foundRecord.getId());
 
             }
 
-            LogRecord foundRecord2 = findLogRecord("test message 2", logRecords2);
+            final LogRecord foundRecord2 = findLogRecord("test message 2", logRecords2);
 
-            assertNotNull("Record2 is not found", foundRecord2);
+            assertNotNull(foundRecord2, "Record2 is not found");
         }
         finally
         {
@@ -216,14 +203,14 @@ public class BrokerLoggerTest extends UnitTestBase
     public void testStatistics()
     {
         Map<String, Object> attributes;
-        String loggerName = getTestName();
-        Logger messageLogger = LoggerFactory.getLogger(loggerName);
+        final String loggerName = getTestName();
+        final Logger messageLogger = LoggerFactory.getLogger(loggerName);
 
         assertEquals(0L, _brokerLogger.getWarnCount());
         assertEquals(0L, _brokerLogger.getErrorCount());
 
         attributes = createBrokerNameAndLevelLogInclusionRuleAttributes(loggerName, LogLevel.WARN);
-        BrokerLogInclusionRule warnFilter = _brokerLogger.createChild(BrokerLogInclusionRule.class, attributes);
+        final BrokerLogInclusionRule warnFilter = _brokerLogger.createChild(BrokerLogInclusionRule.class, attributes);
 
         messageLogger.warn("warn");
         assertEquals(1L, _brokerLogger.getWarnCount());
@@ -236,7 +223,7 @@ public class BrokerLoggerTest extends UnitTestBase
         warnFilter.delete();
 
         attributes = createBrokerNameAndLevelLogInclusionRuleAttributes(loggerName, LogLevel.ERROR);
-        BrokerLogInclusionRule errorFilter = _brokerLogger.createChild(BrokerLogInclusionRule.class, attributes);
+        final BrokerLogInclusionRule errorFilter = _brokerLogger.createChild(BrokerLogInclusionRule.class, attributes);
 
         messageLogger.warn("warn");
         assertEquals(1L, _brokerLogger.getWarnCount());
@@ -256,11 +243,11 @@ public class BrokerLoggerTest extends UnitTestBase
     @Test
     public void testTurningLoggingOff()
     {
-        Map<String, Object> fooRuleAttributes =
+        final Map<String, Object> fooRuleAttributes =
                 createBrokerNameAndLevelLogInclusionRuleAttributes("fooRule",
                                                                    "org.apache.qpid.foo.*",
                                                                    LogLevel.INFO);
-        Map<String, Object> barRuleAttributes =
+        final Map<String, Object> barRuleAttributes =
                 createBrokerNameAndLevelLogInclusionRuleAttributes("barRule",
                                                                    "org.apache.qpid.foo.bar",
                                                                    LogLevel.OFF);
@@ -268,10 +255,10 @@ public class BrokerLoggerTest extends UnitTestBase
         _brokerLogger.createChild(BrokerLogInclusionRule.class, fooRuleAttributes);
         _brokerLogger.createChild(BrokerLogInclusionRule.class, barRuleAttributes);
 
-        Logger barLogger = LoggerFactory.getLogger("org.apache.qpid.foo.bar");
+        final Logger barLogger = LoggerFactory.getLogger("org.apache.qpid.foo.bar");
         barLogger.warn("bar message");
 
-        Logger fooLogger = LoggerFactory.getLogger("org.apache.qpid.foo.foo");
+        final Logger fooLogger = LoggerFactory.getLogger("org.apache.qpid.foo.foo");
         fooLogger.warn("foo message");
 
         assertLoggedEvent(_loggerAppender, false, "bar message", barLogger.getName(), Level.WARN);
@@ -282,11 +269,11 @@ public class BrokerLoggerTest extends UnitTestBase
     @Test
     public void testExactLoggerRuleSupersedeWildCardLoggerRule()
     {
-        Map<String, Object> fooRuleAttributes =
+        final Map<String, Object> fooRuleAttributes =
                 createBrokerNameAndLevelLogInclusionRuleAttributes("fooRule",
                                                                    "org.apache.qpid.foo.*",
                                                                    LogLevel.INFO);
-        Map<String, Object> barRuleAttributes =
+        final Map<String, Object> barRuleAttributes =
                 createBrokerNameAndLevelLogInclusionRuleAttributes("barRule",
                                                                    "org.apache.qpid.foo.bar",
                                                                    LogLevel.WARN);
@@ -294,11 +281,11 @@ public class BrokerLoggerTest extends UnitTestBase
         _brokerLogger.createChild(BrokerLogInclusionRule.class, fooRuleAttributes);
         _brokerLogger.createChild(BrokerLogInclusionRule.class, barRuleAttributes);
 
-        Logger barLogger = LoggerFactory.getLogger("org.apache.qpid.foo.bar");
+        final Logger barLogger = LoggerFactory.getLogger("org.apache.qpid.foo.bar");
         barLogger.info("info bar message");
         barLogger.error("error bar message");
 
-        Logger fooLogger = LoggerFactory.getLogger("org.apache.qpid.foo.foo");
+        final Logger fooLogger = LoggerFactory.getLogger("org.apache.qpid.foo.foo");
         fooLogger.info("info foo message");
 
         assertLoggedEvent(_loggerAppender, false, "info bar message", barLogger.getName(), Level.INFO);
@@ -316,17 +303,15 @@ public class BrokerLoggerTest extends UnitTestBase
                                                                                    final String loggerName,
                                                                                    final LogLevel logLevel)
     {
-        Map<String, Object> attributes = new HashMap<>();
-        attributes.put(BrokerNameAndLevelLogInclusionRule.LOGGER_NAME, loggerName);
-        attributes.put(BrokerNameAndLevelLogInclusionRule.LEVEL, logLevel);
-        attributes.put(BrokerNameAndLevelLogInclusionRule.NAME, ruleName);
-        attributes.put(ConfiguredObject.TYPE, BrokerNameAndLevelLogInclusionRule.TYPE);
-        return attributes;
+        return Map.of(BrokerNameAndLevelLogInclusionRule.LOGGER_NAME, loggerName,
+                BrokerNameAndLevelLogInclusionRule.LEVEL, logLevel,
+                BrokerNameAndLevelLogInclusionRule.NAME, ruleName,
+                ConfiguredObject.TYPE, BrokerNameAndLevelLogInclusionRule.TYPE);
     }
 
-    private LogRecord findLogRecord(String message, Collection<LogRecord> logRecords)
+    private LogRecord findLogRecord(final String message, final Collection<LogRecord> logRecords)
     {
-        for (LogRecord record: logRecords)
+        for (final LogRecord record: logRecords)
         {
             if (message.equals(record.getMessage()))
             {
