@@ -28,7 +28,6 @@ import java.io.IOException;
 import java.io.OutputStream;
 import java.lang.reflect.Method;
 import java.nio.charset.StandardCharsets;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
@@ -37,12 +36,12 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.zip.GZIPOutputStream;
 
-import javax.servlet.ServletConfig;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.ServletConfig;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.fasterxml.jackson.databind.SerializationFeature;
@@ -76,6 +75,8 @@ public abstract class AbstractServlet extends HttpServlet
     public static final String CONTENT_DISPOSITION_ATTACHMENT_FILENAME_PARAM = "contentDispositionAttachmentFilename";
     private static final Logger LOGGER = LoggerFactory.getLogger(AbstractServlet.class);
     public static final String CONTENT_DISPOSITION = "Content-Disposition";
+    protected static final String GENERIC_ERROR_MESSAGE = "There was an error when performing request, " +
+            "see log file for details";
 
     /**
      * Allowed response headers
@@ -255,12 +256,12 @@ public abstract class AbstractServlet extends HttpServlet
         writeObjectToResponse(object, request, response);
     }
 
-    protected final void sendJsonErrorResponse(HttpServletRequest request,
-                                               HttpServletResponse response,
-                                               int responseCode,
-                                               String message) throws IOException
+    protected final void sendJsonErrorResponse(final HttpServletRequest request,
+                                               final HttpServletResponse response,
+                                               final int responseCode,
+                                               final String message) throws IOException
     {
-        sendJsonResponse(Collections.singletonMap("errorMessage", message), request, response, responseCode, false);
+        sendJsonResponse(Map.of("errorMessage", GENERIC_ERROR_MESSAGE), request, response, responseCode, false);
     }
 
     protected void sendError(final HttpServletResponse resp, int responseCode)
@@ -300,7 +301,7 @@ public abstract class AbstractServlet extends HttpServlet
         catch (IOException e)
         {
             LOGGER.warn("Unexpected exception processing request", e);
-            sendJsonErrorResponse(request, response, HttpServletResponse.SC_INTERNAL_SERVER_ERROR, e.getMessage());
+            sendJsonErrorResponse(request, response, HttpServletResponse.SC_INTERNAL_SERVER_ERROR, GENERIC_ERROR_MESSAGE);
         }
     }
 
@@ -351,7 +352,7 @@ public abstract class AbstractServlet extends HttpServlet
 
     private Map<String, Object> getResponseHeaders(final Object content)
     {
-        Map<String, Object> headers = Collections.emptyMap();
+        Map<String, Object> headers = Map.of();
         if (content instanceof CustomRestHeaders)
         {
             CustomRestHeaders customRestHeaders = (CustomRestHeaders) content;
