@@ -43,7 +43,6 @@ import jakarta.servlet.http.Part;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.fasterxml.jackson.databind.SerializationFeature;
-import com.google.common.base.Strings;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -301,7 +300,7 @@ public class RestServlet extends AbstractServlet
 
     private static Map<String, List<String>> parseQueryString(String queryString)
     {
-        if (Strings.isNullOrEmpty(queryString))
+        if (queryString == null || queryString.isEmpty())
         {
             return Map.of();
         }
