@@ -33,8 +33,8 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.Map;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.management.plugin.ManagementResponse;
 import org.apache.qpid.server.management.plugin.ResponseType;
@@ -48,7 +48,7 @@ public class GenericLegacyConfiguredObjectTest extends UnitTestBase
     private static final String CATEGORY = "testCategory";
     private LegacyManagementController _managementController;
 
-    @Before
+    @BeforeEach
     public void setUp()
     {
         _managementController = mock(LegacyManagementController.class);
