@@ -27,10 +27,10 @@ import static org.hamcrest.MatcherAssert.assertThat;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-import java.util.Collections;
+import java.util.Set;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.management.plugin.ManagementController;
 import org.apache.qpid.server.management.plugin.controller.LegacyConfiguredObject;
@@ -40,10 +40,9 @@ import org.apache.qpid.test.utils.UnitTestBase;
 
 public class LegacyCategoryControllerTest extends UnitTestBase
 {
-
     private LegacyCategoryController _controller;
 
-    @Before
+    @BeforeEach
     public void setUp()
     {
         final LegacyManagementController legacyManagementController = mock(LegacyManagementController.class);
@@ -54,7 +53,7 @@ public class LegacyCategoryControllerTest extends UnitTestBase
                                                    VirtualHostNode.TYPE,
                                                    new String[]{BrokerController.TYPE},
                                                    null,
-                                                   Collections.emptySet());
+                                                   Set.of());
     }
 
 
