@@ -18,15 +18,16 @@
  * under the License.
  *
  */
-package org.apache.qpid.server.management.plugin.controller.v6_1.category;
+package org.apache.qpid.server.management.plugin.controller.v7_0.category;
 
+import static org.apache.qpid.server.management.plugin.controller.v7_0.category.LegacyCategoryControllerFactory.SUPPORTED_CATEGORIES;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.mockito.Mockito.mock;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.management.plugin.controller.CategoryController;
 import org.apache.qpid.server.management.plugin.controller.LegacyManagementController;
@@ -37,7 +38,7 @@ public class LegacyCategoryControllerFactoryTest extends UnitTestBase
     private LegacyCategoryControllerFactory _factory;
     private LegacyManagementController _nextVersionManagementController;
 
-    @Before
+    @BeforeEach
     public void setUp()
     {
         _nextVersionManagementController = mock(LegacyManagementController.class);
@@ -47,17 +48,10 @@ public class LegacyCategoryControllerFactoryTest extends UnitTestBase
     @Test
     public void createController()
     {
-        LegacyCategoryControllerFactory.SUPPORTED_CATEGORIES.forEach(category -> {
+        SUPPORTED_CATEGORIES.keySet().forEach(category-> {
             final CategoryController controller =
                     _factory.createController(category, _nextVersionManagementController);
             assertThat(controller.getCategory(), is(equalTo(category)));
         });
     }
-
-    @Test
-    public void getSupportedCategories()
-    {
-        assertThat(_factory.getSupportedCategories(),
-                   is(equalTo(LegacyCategoryControllerFactory.SUPPORTED_CATEGORIES)));
-    }
-}
\ No newline at end of file
+}
