@@ -20,13 +20,12 @@
  */
 package org.apache.qpid.server.transport.websocket;
 
-import java.io.IOException;
-import java.lang.reflect.Field;
 import java.net.SocketAddress;
 import java.nio.ByteBuffer;
 import java.security.Principal;
 import java.security.cert.Certificate;
 import java.security.cert.X509Certificate;
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
@@ -39,28 +38,33 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLEngine;
 import javax.net.ssl.SSLParameters;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
 
+import jakarta.servlet.http.HttpServletResponse;
+
+import org.eclipse.jetty.ee11.websocket.server.JettyWebSocketCreator;
+import org.eclipse.jetty.ee11.websocket.server.JettyWebSocketServerContainer;
+import org.eclipse.jetty.ee11.websocket.server.JettyWebSocketServlet;
+import org.eclipse.jetty.ee11.websocket.server.JettyWebSocketServletFactory;
 import org.eclipse.jetty.io.ssl.SslHandshakeListener;
+import org.eclipse.jetty.server.Handler;
 import org.eclipse.jetty.server.HttpConnectionFactory;
 import org.eclipse.jetty.server.Request;
+import org.eclipse.jetty.server.Response;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.server.ServerConnector;
-import org.eclipse.jetty.server.handler.AbstractHandler;
+import org.eclipse.jetty.server.handler.ContextHandlerCollection;
+import org.eclipse.jetty.ee11.servlet.ServletContextHandler;
+import org.eclipse.jetty.ee11.servlet.ServletHolder;
 import org.eclipse.jetty.util.ssl.SslContextFactory;
 import org.eclipse.jetty.util.thread.QueuedThreadPool;
 import org.eclipse.jetty.util.thread.ThreadPool;
+import org.eclipse.jetty.websocket.api.Callback;
 import org.eclipse.jetty.websocket.api.Session;
-import org.eclipse.jetty.websocket.api.WebSocketPolicy;
 import org.eclipse.jetty.websocket.api.annotations.OnWebSocketClose;
-import org.eclipse.jetty.websocket.api.annotations.OnWebSocketConnect;
 import org.eclipse.jetty.websocket.api.annotations.OnWebSocketMessage;
+import org.eclipse.jetty.websocket.api.annotations.OnWebSocketOpen;
 import org.eclipse.jetty.websocket.api.annotations.WebSocket;
-import org.eclipse.jetty.websocket.server.WebSocketHandler;
-import org.eclipse.jetty.websocket.servlet.ServletUpgradeRequest;
-import org.eclipse.jetty.websocket.servlet.WebSocketServletFactory;
+import org.eclipse.jetty.websocket.core.server.WebSocketServerComponents;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -90,8 +94,6 @@ class WebSocketProvider implements AcceptingTransport
     private final SslContextFactory.Server _sslContextFactory;
     private final AmqpPort<?> _port;
     private final Broker<?> _broker;
-    private final Set<Protocol> _supported;
-    private final Protocol _defaultSupportedProtocolReply;
     private final MultiVersionProtocolEngineFactory _factory;
 
     private Server _server;
@@ -111,17 +113,13 @@ class WebSocketProvider implements AcceptingTransport
         _sslContextFactory = transport == Transport.WSS ? createSslContextFactory(port) : null;
         _port = port;
         _broker = ((Broker<?>) port.getParent());
-        _supported = supported;
-        _defaultSupportedProtocolReply = defaultSupportedProtocolReply;
 
         _factory = new MultiVersionProtocolEngineFactory(
-                        _broker,
-                        _supported,
-                        _defaultSupportedProtocolReply,
-                        _port,
-                        _transport);
-
-
+                _broker,
+                supported,
+                defaultSupportedProtocolReply,
+                _port,
+                _transport);
     }
 
     @Override
@@ -132,7 +130,7 @@ class WebSocketProvider implements AcceptingTransport
         _server = new Server(new QBBTrackingThreadPool());
 
         final ServerConnector connector;
-        HttpConnectionFactory httpConnectionFactory = new HttpConnectionFactory();
+        final HttpConnectionFactory httpConnectionFactory = new HttpConnectionFactory();
         httpConnectionFactory.getHttpConfiguration().setSendServerVersion(false);
         httpConnectionFactory.getHttpConfiguration().setSendXPoweredBy(false);
 
@@ -148,7 +146,7 @@ class WebSocketProvider implements AcceptingTransport
                 @Override
                 public void handshakeFailed(final Event event, final Throwable failure)
                 {
-                    SSLEngine sslEngine = event.getSSLEngine();
+                    final SSLEngine sslEngine = event.getSSLEngine();
                     if (LOGGER.isDebugEnabled())
                     {
                         LOGGER.info("TLS handshake failed: host='{}', port={}",
@@ -171,9 +169,9 @@ class WebSocketProvider implements AcceptingTransport
             throw new IllegalArgumentException("Unexpected transport on port " + _port.getName() + ":" + _transport);
         }
 
-        String bindingAddress = _port.getBindingAddress();
+        final String bindingAddress = _port.getBindingAddress();
 
-        if (bindingAddress != null && !bindingAddress.trim().equals("") && !bindingAddress.trim().equals("*"))
+        if (bindingAddress != null && !bindingAddress.trim().isEmpty() && !"*".equals(bindingAddress.trim()))
         {
             connector.setHost(bindingAddress.trim());
         }
@@ -181,63 +179,56 @@ class WebSocketProvider implements AcceptingTransport
         connector.setPort(_port.getPort());
         _server.addConnector(connector);
 
-        WebSocketHandler wshandler = new WebSocketHandler()
+        final JettyWebSocketCreator jettyWebSocketCreator = (request, response) ->
+        {
+            response.setAcceptedSubProtocol(AMQP_WEBSOCKET_SUBPROTOCOL);
+            return new AmqpWebSocket(request.getCertificates());
+        };
+
+        final JettyWebSocketServlet websocketServlet = new JettyWebSocketServlet()
         {
             @Override
-            public void configure(final WebSocketServletFactory factory)
+            public void configure(final JettyWebSocketServletFactory factory)
             {
-                factory.setCreator((req, resp) ->
-                {
-                    resp.setAcceptedSubProtocol(AMQP_WEBSOCKET_SUBPROTOCOL);
-                    return new AmqpWebSocket();
-                });
-            }
-
-            @Override
-            public void configurePolicy(final WebSocketPolicy policy)
-            {
-                super.configurePolicy(policy);
-                // It seems Jetty internally makes provision for maxBinaryMessageSize to be unconstrained, but the
-                // policy does not allow it to be configured it that way.
-                // See https://github.com/eclipse/jetty.project/issues/488
-                try
-                {
-                    Field maxBinaryMessageSize = policy.getClass().getDeclaredField("maxBinaryMessageSize");
-                    maxBinaryMessageSize.setAccessible(true);
-                    maxBinaryMessageSize.set(policy, 0);
-                }
-                catch (IllegalAccessException | NoSuchFieldException e)
-                {
-                    LOGGER.warn("Could not override maxBinaryMessageSize", e);
-                }
+                factory.setMaxBinaryMessageSize(0L);
+                factory.setCreator(jettyWebSocketCreator);
             }
         };
 
-        _server.setHandler(wshandler);
-        wshandler.setHandler(new AbstractHandler()
+        final ServletContextHandler servletContextHandler = new ServletContextHandler();
+        servletContextHandler.setContextPath("/");
+        servletContextHandler.addServlet(new ServletHolder(websocketServlet), "");
+        servletContextHandler.setServer(_server);
+
+        WebSocketServerComponents.ensureWebSocketComponents(_server, servletContextHandler);
+        JettyWebSocketServerContainer.ensureContainer(servletContextHandler.getServletContext())
+                .addMapping("/", jettyWebSocketCreator);
+
+        final ContextHandlerCollection handlers = new ContextHandlerCollection();
+        handlers.addHandler(servletContextHandler);
+        handlers.addHandler(new Handler.Abstract()
         {
             @Override
-            public void handle(final String target,
-                               final Request baseRequest,
-                               final HttpServletRequest request,
-                               final HttpServletResponse response)
-                    throws IOException, ServletException
+            public boolean handle(final Request request,
+                                  final Response response,
+                                  final org.eclipse.jetty.util.Callback callback)
             {
-                if (response.isCommitted() || baseRequest.isHandled())
+                if (response.isCommitted())
                 {
-                    return;
+                    return false;
                 }
-                baseRequest.setHandled(true);
+                callback.succeeded();
                 response.setStatus(HttpServletResponse.SC_FORBIDDEN);
-
-
+                return true;
             }
         });
+        _server.setHandler(handlers);
+
         try
         {
             _server.start();
         }
-        catch(RuntimeException e)
+        catch (RuntimeException e)
         {
             throw e;
         }
@@ -245,12 +236,11 @@ class WebSocketProvider implements AcceptingTransport
         {
             throw new ServerScopedRuntimeException(e);
         }
-
     }
 
     private SslContextFactory.Server createSslContextFactory(final AmqpPort<?> port)
     {
-        SslContextFactory.Server sslContextFactory = new SslContextFactory.Server()
+        final SslContextFactory.Server sslContextFactory = new SslContextFactory.Server()
         {
             @Override
             public void customize(final SSLEngine sslEngine)
@@ -263,10 +253,9 @@ class WebSocketProvider implements AcceptingTransport
                                                   port.getTlsProtocolAllowList(),
                                                   port.getTlsProtocolDenyList());
 
-                if (port.getTlsCipherSuiteAllowList() != null
-                    && !port.getTlsCipherSuiteAllowList().isEmpty())
+                if (port.getTlsCipherSuiteAllowList() != null && !port.getTlsCipherSuiteAllowList().isEmpty())
                 {
-                    SSLParameters sslParameters = sslEngine.getSSLParameters();
+                    final SSLParameters sslParameters = sslEngine.getSSLParameters();
                     sslParameters.setUseCipherSuitesOrder(true);
                     sslEngine.setSSLParameters(sslParameters);
                 }
@@ -297,7 +286,7 @@ class WebSocketProvider implements AcceptingTransport
     @Override
     public int getAcceptingPort()
     {
-        Server server = _server;
+        final Server server = _server;
         return server == null || server.getConnectors().length == 0 || !(server.getConnectors()[0] instanceof ServerConnector) ?
                 _port.getPort() :
                 ((ServerConnector) server.getConnectors()[0]).getLocalPort();
@@ -310,9 +299,9 @@ class WebSocketProvider implements AcceptingTransport
         {
             try
             {
-                _sslContextFactory.reload(f ->
+                _sslContextFactory.reload(sslContextFactory ->
                 {
-                    final SslContextFactory.Server server = (SslContextFactory.Server) f;
+                    final SslContextFactory.Server server = (SslContextFactory.Server) sslContextFactory;
                     server.setSslContext(_port.getSSLContext());
                     server.setNeedClientAuth(_port.getNeedClientAuth());
                     server.setWantClientAuth(_port.getWantClientAuth());
@@ -342,44 +331,44 @@ class WebSocketProvider implements AcceptingTransport
     @WebSocket
     public class AmqpWebSocket
     {
+        final X509Certificate[] _certificates;
         private volatile QpidByteBuffer _netInputBuffer;
         private volatile MultiVersionProtocolEngine _protocolEngine;
         private volatile ConnectionWrapper _connectionWrapper;
         private volatile boolean _unexpectedByteBufferSizeReported;
 
-        AmqpWebSocket()
+        AmqpWebSocket(final X509Certificate[] certificates)
         {
             _netInputBuffer = QpidByteBuffer.allocateDirect(_broker.getNetworkBufferSize());
+            _certificates = certificates;
         }
 
-        @OnWebSocketConnect @SuppressWarnings("unused")
+        @OnWebSocketOpen
+        @SuppressWarnings("unused")
         public void onWebSocketConnect(final Session session)
         {
-            SocketAddress localAddress = session.getLocalAddress();
-            SocketAddress remoteAddress = session.getRemoteAddress();
+            final SocketAddress localAddress = session.getLocalSocketAddress();
+            final SocketAddress remoteAddress = session.getRemoteSocketAddress();
             _protocolEngine = _factory.newProtocolEngine(remoteAddress);
 
             // Let AMQP do timeout handling
-            session.setIdleTimeout(0);
+            session.setIdleTimeout(Duration.ZERO);
 
             _connectionWrapper = new ConnectionWrapper(session, localAddress, remoteAddress, _protocolEngine, _server.getThreadPool());
-            if (session.getUpgradeRequest() instanceof ServletUpgradeRequest)
+
+            if (_certificates != null && _certificates.length > 0)
             {
-                ServletUpgradeRequest upgradeRequest = (ServletUpgradeRequest) session.getUpgradeRequest();
-                if (upgradeRequest.getCertificates() != null && upgradeRequest.getCertificates().length > 0)
-                {
-                    _connectionWrapper.setPeerCertificate(upgradeRequest.getCertificates()[0]);
-                }
+                _connectionWrapper.setPeerCertificate(_certificates[0]);
             }
             _protocolEngine.setNetworkConnection(_connectionWrapper);
             _protocolEngine.setWorkListener(object -> _server.getThreadPool().execute(() -> _connectionWrapper.doWork()));
             _activeConnections.add(_connectionWrapper);
             _idleTimeoutChecker.wakeup();
-
         }
 
-        @OnWebSocketMessage @SuppressWarnings("unused")
-        public void onWebSocketBinary(Session sess, final byte[] payload, int offset, final int len)
+        @OnWebSocketMessage
+        @SuppressWarnings("unused")
+        public void onWebSocketBinary(ByteBuffer payload, boolean last, Callback callback)
         {
             synchronized (_connectionWrapper)
             {
@@ -388,17 +377,21 @@ class WebSocketProvider implements AcceptingTransport
                 {
                     _protocolEngine.setIOThread(Thread.currentThread());
                     Iterator<Runnable> iter = _protocolEngine.processPendingIterator();
-                    while(iter.hasNext())
+                    while (iter.hasNext())
                     {
                         iter.next().run();
                     }
 
+                    byte[] bytes = new byte[payload.remaining()];
+                    payload.get(bytes);
+                    int len = bytes.length;
+                    int offset = 0;
                     int lastRead;
                     int remaining = len;
                     do
                     {
                         int chunkLen = Math.min(remaining, _netInputBuffer.remaining());
-                        _netInputBuffer.put(payload, offset, chunkLen);
+                        _netInputBuffer.put(bytes, offset, chunkLen);
                         remaining -= chunkLen;
                         offset += chunkLen;
 
@@ -464,11 +457,11 @@ class WebSocketProvider implements AcceptingTransport
             if (!_unexpectedByteBufferSizeReported)
             {
                 LOGGER.info("At least one frame unexpectedly does not fit into default byte buffer size ({}B) on a connection {}.",
-                            _broker.getNetworkBufferSize(), this.toString());
+                            _broker.getNetworkBufferSize(), this);
                 _unexpectedByteBufferSizeReported = true;
             }
         }
-        
+
         /** AMQP frames MUST be sent as binary data payloads of WebSocket messages.*/
         @OnWebSocketMessage @SuppressWarnings("unused")
         public void onWebSocketText(Session sess, String text)
@@ -477,7 +470,8 @@ class WebSocketProvider implements AcceptingTransport
             sess.close();
         }
 
-        @OnWebSocketClose @SuppressWarnings("unused")
+        @OnWebSocketClose
+        @SuppressWarnings("unused")
         public void onWebSocketClose(final int statusCode, final String reason)
         {
             if (_protocolEngine != null)
@@ -515,18 +509,14 @@ class WebSocketProvider implements AcceptingTransport
             _remoteAddress = remoteAddress;
             _protocolEngine = protocolEngine;
             _threadPool = threadPool;
-            _tickJob = new Runnable()
-                        {
-                            @Override
-                            public void run()
-                            {
-                                synchronized (ConnectionWrapper.this)
-                                {
-                                    protocolEngine.getAggregateTicker().tick(System.currentTimeMillis());
-                                    doWrite();
-                                }
-                            }
-                        };
+            _tickJob = () ->
+            {
+                synchronized (ConnectionWrapper.this)
+                {
+                    protocolEngine.getAggregateTicker().tick(System.currentTimeMillis());
+                    doWrite();
+                }
+            };
         }
 
         @Override
@@ -595,7 +585,7 @@ class WebSocketProvider implements AcceptingTransport
         @Override
         public Principal getPeerPrincipal()
         {
-            return _certificate instanceof X509Certificate ? ((X509Certificate)_certificate).getSubjectDN() : null;
+            return _certificate instanceof X509Certificate ? ((X509Certificate)_certificate).getSubjectX500Principal() : null;
         }
 
         @Override
@@ -672,20 +662,12 @@ class WebSocketProvider implements AcceptingTransport
                 tmp.dispose();
                 offset += remaining;
             }
-            if(size > 0)
+            if (size > 0)
             {
-                try
+                _connection.sendBinary(ByteBuffer.wrap(data), Callback.NOOP);
+                if (LOGGER.isDebugEnabled())
                 {
-                    _connection.getRemote().sendBytes(ByteBuffer.wrap(data));
-                    if (LOGGER.isDebugEnabled())
-                    {
-                        LOGGER.debug("Written {} byte(s)", data.length);
-                    }
-                }
-                catch (IOException e)
-                {
-                    LOGGER.info("Exception on write: {}", e.getMessage());
-                    close();
+                    LOGGER.debug("Written {} byte(s)", data.length);
                 }
             }
         }
