@@ -23,7 +23,8 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
-import java.nio.charset.StandardCharsets;
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
@@ -37,22 +38,27 @@ import javax.jms.QueueBrowser;
 import javax.jms.Session;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
-import org.apache.http.HttpHost;
-import org.apache.http.HttpRequest;
-import org.apache.http.auth.AuthScope;
-import org.apache.http.auth.UsernamePasswordCredentials;
-import org.apache.http.client.CredentialsProvider;
-import org.apache.http.client.methods.CloseableHttpResponse;
-import org.apache.http.client.methods.HttpDelete;
-import org.apache.http.client.methods.HttpGet;
-import org.apache.http.client.methods.HttpPut;
-import org.apache.http.client.protocol.HttpClientContext;
-import org.apache.http.entity.StringEntity;
-import org.apache.http.impl.auth.BasicScheme;
-import org.apache.http.impl.client.BasicAuthCache;
-import org.apache.http.impl.client.BasicCredentialsProvider;
-import org.apache.http.impl.client.CloseableHttpClient;
-import org.apache.http.impl.client.HttpClients;
+import org.apache.hc.client5.http.auth.AuthScope;
+import org.apache.hc.client5.http.auth.CredentialsProvider;
+import org.apache.hc.client5.http.auth.CredentialsStore;
+import org.apache.hc.client5.http.auth.UsernamePasswordCredentials;
+import org.apache.hc.client5.http.classic.methods.HttpDelete;
+import org.apache.hc.client5.http.classic.methods.HttpGet;
+import org.apache.hc.client5.http.classic.methods.HttpPut;
+import org.apache.hc.client5.http.classic.methods.HttpUriRequest;
+import org.apache.hc.client5.http.impl.auth.BasicAuthCache;
+import org.apache.hc.client5.http.impl.auth.BasicCredentialsProvider;
+import org.apache.hc.client5.http.impl.auth.BasicScheme;
+import org.apache.hc.client5.http.impl.classic.CloseableHttpClient;
+import org.apache.hc.client5.http.impl.classic.HttpClients;
+import org.apache.hc.client5.http.protocol.HttpClientContext;
+import org.apache.hc.core5.http.ClassicHttpResponse;
+import org.apache.hc.core5.http.ContentType;
+import org.apache.hc.core5.http.HttpHost;
+import org.apache.hc.core5.http.ProtocolVersion;
+import org.apache.hc.core5.http.io.HttpClientResponseHandler;
+import org.apache.hc.core5.http.io.entity.StringEntity;
+import org.apache.qpid.disttest.json.ObjectMapperFactory;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -75,7 +81,7 @@ public class QpidRestAPIQueueCreator implements QueueCreator
 
     private final CredentialsProvider _credentialsProvider;
 
-    public QpidRestAPIQueueCreator()
+    public QpidRestAPIQueueCreator() throws URISyntaxException
     {
         final String managementUser = System.getProperty("perftests.manangement-user", "guest");
         final String managementPassword = System.getProperty("perftests.manangement-password", "guest");
@@ -271,11 +277,8 @@ public class QpidRestAPIQueueCreator implements QueueCreator
     private void managementCreateQueue(final String name, final HttpClientContext context)
     {
         HttpPut put = new HttpPut(String.format(_queueApiUrl, _virtualhostnode, _virtualhost, name));
-
-        StringEntity input = new StringEntity("{}", StandardCharsets.UTF_8);
-        input.setContentType("application/json");
+        StringEntity input = new StringEntity("{}", ContentType.APPLICATION_JSON, "UTF_8", false);
         put.setEntity(input);
-
         executeManagement(put, context);
     }
 
@@ -285,33 +288,13 @@ public class QpidRestAPIQueueCreator implements QueueCreator
         executeManagement(delete, context);
     }
 
-    private Object executeManagement(final HttpRequest httpRequest, final HttpClientContext context)
+    private Object executeManagement(final HttpUriRequest httpRequest, final HttpClientContext context)
     {
-        try(CloseableHttpClient httpClient = HttpClients.custom()
-                                                        .setDefaultCredentialsProvider(_credentialsProvider)
-                                                        .build();
-            CloseableHttpResponse response = httpClient.execute(_management, httpRequest, context))
+        try (final CloseableHttpClient httpClient = HttpClients.custom()
+                    .setDefaultCredentialsProvider(_credentialsProvider)
+                    .build())
         {
-            int statusCode = response.getStatusLine().getStatusCode();
-            if (statusCode != 200 && statusCode != 201)
-            {
-                throw new RuntimeException(String.format("Failed : HTTP error code : %d  status line : %s", statusCode,
-                                                         response.getStatusLine()));
-            }
-
-            if (response.getEntity() != null)
-            {
-                try (ByteArrayOutputStream bos = new ByteArrayOutputStream())
-                {
-                    response.getEntity().writeTo(bos);
-                    if (bos.size() > 0)
-                    {
-                        return new ObjectMapper().readValue(bos.toByteArray(), Object.class);
-                    }
-                }
-            }
-            return null;
-
+            return httpClient.execute(_management, httpRequest, context, new ResponseHandler());
         }
         catch (IOException e)
         {
@@ -321,18 +304,54 @@ public class QpidRestAPIQueueCreator implements QueueCreator
 
     private HttpClientContext getHttpClientContext(final HttpHost management)
     {
+        final HttpClientContext localContext = HttpClientContext.create();
         final BasicAuthCache authCache = new BasicAuthCache();
-        authCache.put(management, new BasicScheme());
-        HttpClientContext localContext = HttpClientContext.create();
+        final BasicScheme basicScheme = new BasicScheme();
+        basicScheme.initPreemptive(_credentialsProvider.getCredentials(new AuthScope(management), localContext));
+        authCache.put(management, basicScheme);
         localContext.setAuthCache(authCache);
         return localContext;
     }
 
     private CredentialsProvider getCredentialsProvider(final String managementUser, final String managementPassword)
     {
-        final CredentialsProvider credentialsProvider = new BasicCredentialsProvider();
-        credentialsProvider.setCredentials(AuthScope.ANY, new UsernamePasswordCredentials(managementUser, managementPassword));
+        final URI managementURI = URI.create(System.getProperty("perftests.manangement-url"));
+        final String hostname = managementURI.getHost();
+        final int port = managementURI.getPort();
+        final AuthScope authScope = new AuthScope(hostname, port);
+        final CredentialsStore credentialsProvider = new BasicCredentialsProvider();
+        credentialsProvider.setCredentials(authScope, new UsernamePasswordCredentials(managementUser, managementPassword.toCharArray()));
         return credentialsProvider;
     }
 
+    static class ResponseHandler implements HttpClientResponseHandler<Object>
+    {
+        private static final ObjectMapper OBJECT_MAPPER = new ObjectMapperFactory().createObjectMapper();
+
+        @Override
+        public Object handleResponse(ClassicHttpResponse response) throws IOException
+        {
+            final int status = response.getCode();
+            final ProtocolVersion version = response.getVersion();
+            final String reason = response.getReasonPhrase();
+            if (status != 200 && status != 201)
+            {
+                final String msg = String.format("Failed: HTTP error code: %d, Version: %s, Reason: %s", status, version, reason);
+                throw new RuntimeException(msg);
+            }
+
+            if (response.getEntity() != null)
+            {
+                try (ByteArrayOutputStream bos = new ByteArrayOutputStream())
+                {
+                    response.getEntity().writeTo(bos);
+                    if (bos.size() > 0)
+                    {
+                        return OBJECT_MAPPER.readValue(bos.toByteArray(), Object.class);
+                    }
+                }
+            }
+            return null;
+        }
+    }
 }
