@@ -18,31 +18,17 @@
  */
 package org.apache.qpid.disttest.jms;
 
-import org.junit.Assert;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 
 import org.apache.qpid.disttest.message.Command;
 import org.apache.qpid.disttest.message.CommandType;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.After;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.test.utils.UnitTestBase;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.fail;
-import static org.junit.Assert.assertNotNull;
-
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
 
 public class JmsMessageAdaptorTest extends UnitTestBase
 {
-
     @Test
     public void testCheckAllCommandTypes()
     {
@@ -51,7 +37,5 @@ public class JmsMessageAdaptorTest extends UnitTestBase
             Class<? extends Command> clazz = JmsMessageAdaptor.getCommandClassFromType(commandType);
             assertNotNull(clazz);
         }
-
     }
-
 }
