@@ -26,14 +26,12 @@ import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.emptyString;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
-import java.util.Collections;
 import java.util.Map;
 
-import org.hamcrest.Matchers;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.exchange.ExchangeDefaults;
 import org.apache.qpid.server.filter.AMQPFilterTypes;
@@ -159,7 +157,7 @@ public class QueueTest extends BrokerAdminUsingTestBase
             assertThat(response.getConsumerCount(), is(equalTo(0L)));
         }
 
-        assumeThat(getBrokerAdmin().supportsRestart(), Matchers.is(true));
+        assumeTrue(getBrokerAdmin().supportsRestart());
         getBrokerAdmin().restart();
 
         try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
@@ -224,7 +222,7 @@ public class QueueTest extends BrokerAdminUsingTestBase
     @Test
     @SpecificationTest(section = "1.7.2.1",
             description = "The server MUST ignore the auto-delete field if the queue already exists.")
-    @Ignore("The server does not ignore the auto-delete field if the queue already exists.")
+    @Disabled("The server does not ignore the auto-delete field if the queue already exists.")
     public void queueDeclareAutoDeletePreexistingQueue() throws Exception
     {
         try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
@@ -587,7 +585,7 @@ public class QueueTest extends BrokerAdminUsingTestBase
             assertThat(response.getReplyCode(), is(equalTo(ExchangeBoundOkBody.OK)));
         }
 
-        assumeThat(getBrokerAdmin().supportsRestart(), Matchers.is(true));
+        assumeTrue(getBrokerAdmin().supportsRestart());
         getBrokerAdmin().restart();
 
         try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
@@ -844,7 +842,7 @@ public class QueueTest extends BrokerAdminUsingTestBase
                        .consumeResponse(ExchangeDeclareOkBody.class)
                        .queue()
                        .declareName(BrokerAdmin.TEST_QUEUE_NAME)
-                       .declareArguments(Collections.singletonMap("alternateExchange", altExchName)).declare()
+                       .declareArguments(Map.of("alternateExchange", altExchName)).declare()
                        .consumeResponse(QueueDeclareOkBody.class);
 
             ChannelCloseBody inUseResponse = interaction.exchange()
@@ -877,7 +875,7 @@ public class QueueTest extends BrokerAdminUsingTestBase
                                                       .channel().open().consumeResponse(ChannelOpenOkBody.class)
                                                       .queue()
                                                       .declareName(BrokerAdmin.TEST_QUEUE_NAME)
-                                                      .declareArguments(Collections.singletonMap("alternateExchange", "notKnown")).declare()
+                                                      .declareArguments(Map.of("alternateExchange", "notKnown")).declare()
                                                       .consumeResponse().getLatestResponse(ConnectionCloseBody.class);
             assertThat(response.getReplyCode(), is(equalTo(ErrorCodes.NOT_FOUND)));
         }
@@ -894,7 +892,7 @@ public class QueueTest extends BrokerAdminUsingTestBase
         try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            final Map<String, Object> messageProps = Collections.singletonMap("prop", 0);
+            final Map<String, Object> messageProps = Map.of("prop", 0);
             interaction.negotiateOpen()
                        .channel().open().consumeResponse(ChannelOpenOkBody.class)
                        .tx().select()
@@ -903,7 +901,7 @@ public class QueueTest extends BrokerAdminUsingTestBase
                        .bindName(ExchangeDefaults.TOPIC_EXCHANGE_NAME)
                        .bindRoutingKey(routingKey)
                        .bindQueueName(BrokerAdmin.TEST_QUEUE_NAME)
-                       .bindArguments(Collections.singletonMap(AMQPFilterTypes.JMS_SELECTOR.getValue(), "prop = 1"))
+                       .bindArguments(Map.of(AMQPFilterTypes.JMS_SELECTOR.getValue(), "prop = 1"))
                        .bind()
                        .consumeResponse(QueueBindOkBody.class)
                        .basic()
@@ -921,7 +919,7 @@ public class QueueTest extends BrokerAdminUsingTestBase
                        .bindName(ExchangeDefaults.TOPIC_EXCHANGE_NAME)
                        .bindRoutingKey(routingKey)
                        .bindQueueName(BrokerAdmin.TEST_QUEUE_NAME)
-                       .bindArguments(Collections.singletonMap(AMQPFilterTypes.JMS_SELECTOR.getValue(), "prop = 0"))
+                       .bindArguments(Map.of(AMQPFilterTypes.JMS_SELECTOR.getValue(), "prop = 0"))
                        .bind()
                        .consumeResponse(QueueBindOkBody.class)
                        .basic().publishExchange(ExchangeDefaults.TOPIC_EXCHANGE_NAME)
