@@ -30,15 +30,13 @@ import static org.hamcrest.Matchers.is;
 import static org.hamcrest.Matchers.lessThan;
 import static org.hamcrest.Matchers.notNullValue;
 import static org.hamcrest.Matchers.nullValue;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
-import java.net.InetSocketAddress;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.bytebuffer.QpidByteBuffer;
 import org.apache.qpid.server.protocol.v1_0.type.Symbol;
@@ -67,7 +65,7 @@ import org.apache.qpid.tests.utils.ConfigItem;
 @ConfigItem(name = "qpid.tests.mms.messagestore.persistence", value = "false", jvm = true)
 public class FilterTest extends BrokerAdminUsingTestBase
 {
-    @Before
+    @BeforeEach
     public void setUp()
     {
         getBrokerAdmin().createQueue(BrokerAdmin.TEST_QUEUE_NAME);
@@ -87,13 +85,12 @@ public class FilterTest extends BrokerAdminUsingTestBase
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class);
             Flow flow = interaction.getLatestResponse(Flow.class);
-            assumeThat("insufficient credit for the test", flow.getLinkCredit().intValue(), is(greaterThan(1)));
+            assumeTrue(is(greaterThan(1)).matches(flow.getLinkCredit().intValue()), "insufficient credit for the test");
 
             for (int i = 0; i < 2; i++)
             {
                 QpidByteBuffer payload =
-                        generateMessagePayloadWithApplicationProperties(Collections.singletonMap("index", i),
-                                                                        getTestName());
+                        generateMessagePayloadWithApplicationProperties(Map.of("index", i), getTestName());
                 interaction.transferPayload(payload)
                            .transferSettled(true)
                            .transfer();
@@ -109,8 +106,7 @@ public class FilterTest extends BrokerAdminUsingTestBase
                        .attachRole(Role.RECEIVER)
                        .attachSourceAddress(BrokerAdmin.TEST_QUEUE_NAME)
                        .attachRcvSettleMode(ReceiverSettleMode.FIRST)
-                       .attachSourceFilter(Collections.singletonMap(Symbol.valueOf("selector-filter"),
-                                                                    new JMSSelectorFilter("index=1")))
+                       .attachSourceFilter(Map.of(Symbol.valueOf("selector-filter"), new JMSSelectorFilter("index=1")))
                        .attach().consumeResponse()
                        .flowIncomingWindow(UnsignedInteger.ONE)
                        .flowNextIncomingId(UnsignedInteger.ZERO)
