@@ -25,14 +25,6 @@ import static org.hamcrest.Matchers.instanceOf;
 import static org.hamcrest.Matchers.is;
 import static org.hamcrest.Matchers.nullValue;
 
-import java.net.InetSocketAddress;
-import java.util.concurrent.ArrayBlockingQueue;
-import java.util.concurrent.BlockingQueue;
-import java.util.concurrent.TimeUnit;
-
-import com.google.common.base.Preconditions;
-import com.google.common.util.concurrent.JdkFutureAdapters;
-import com.google.common.util.concurrent.ListenableFuture;
 import io.netty.bootstrap.Bootstrap;
 import io.netty.buffer.ByteBuf;
 import io.netty.buffer.ByteBufAllocator;
@@ -42,9 +34,18 @@ import io.netty.channel.ChannelOption;
 import io.netty.channel.ChannelPipeline;
 import io.netty.channel.ChannelPromise;
 import io.netty.channel.EventLoopGroup;
-import io.netty.channel.nio.NioEventLoopGroup;
+import io.netty.channel.MultiThreadIoEventLoopGroup;
+import io.netty.channel.nio.NioIoHandler;
 import io.netty.channel.socket.SocketChannel;
 import io.netty.channel.socket.nio.NioSocketChannel;
+import io.netty.util.concurrent.Future;
+
+import java.net.InetSocketAddress;
+import java.util.Objects;
+import java.util.concurrent.ArrayBlockingQueue;
+import java.util.concurrent.BlockingQueue;
+import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.TimeUnit;
 
 public abstract class AbstractFrameTransport<I extends AbstractInteraction<I>> implements AutoCloseable
 {
@@ -68,7 +69,7 @@ public abstract class AbstractFrameTransport<I extends AbstractInteraction<I>> i
         _brokerAddress = brokerAddress;
         _inputHandler = new InputHandler(_queue, inputDecoder);
         _outputHandler = new OutputHandler(outputEncoder);
-        _workerGroup = new NioEventLoopGroup();
+        _workerGroup = new MultiThreadIoEventLoopGroup(NioIoHandler.newFactory());
     }
 
     public InetSocketAddress getBrokerAddress()
@@ -131,27 +132,31 @@ public abstract class AbstractFrameTransport<I extends AbstractInteraction<I>> i
         }
     }
 
-    ListenableFuture<Void> sendProtocolHeader(final byte[] bytes)
+    CompletableFuture<Void> sendProtocolHeader(final byte[] bytes)
     {
         return sendBytes(bytes);
     }
 
-    public ListenableFuture<Void> sendBytes(final byte[] bytes)
+    public CompletableFuture<Void> sendBytes(final byte[] bytes)
     {
-        Preconditions.checkState(_channel != null, "Not connected");
+        Objects.requireNonNull(_channel, "Not connected");
         final ChannelPromise promise = _channel.newPromise();
         final ByteBuf buffer = ByteBufAllocator.DEFAULT.buffer();
         buffer.writeBytes(bytes);
         _channel.write(buffer, promise);
-        return JdkFutureAdapters.listenInPoolThread(promise);
+        final CompletableFuture<Void> result = new CompletableFuture<>();
+        promise.addListener(future -> completeFuture(future, result));
+        return result;
     }
 
-    public ListenableFuture<Void> sendPerformative(final Object data) throws Exception
+    public CompletableFuture<Void> sendPerformative(final Object data) throws Exception
     {
-        Preconditions.checkState(_channel != null, "Not connected");
+        Objects.requireNonNull(_channel, "Not connected");
         final ChannelPromise promise = _channel.newPromise();
         _channel.write(data, promise);
-        return JdkFutureAdapters.listenInPoolThread(promise);
+        final CompletableFuture<Void> result = new CompletableFuture<>();
+        promise.addListener(future -> completeFuture(future, result));
+        return result;
     }
 
     <T extends Response<?>> T getNextResponse() throws Exception
@@ -176,6 +181,18 @@ public abstract class AbstractFrameTransport<I extends AbstractInteraction<I>> i
         _channel.flush();
     }
 
+    private static void completeFuture(Future<? super Void> future, CompletableFuture<Void> result)
+    {
+        if (future.isSuccess())
+        {
+            result.complete(null);
+        }
+        else
+        {
+            result.completeExceptionally(future.cause());
+        }
+    }
+
     public abstract byte[] getProtocolHeader();
 
     public abstract I newInteraction();
