@@ -58,8 +58,6 @@ import jakarta.servlet.http.HttpServletResponse;
 import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.ObjectMapper;
 
-import com.google.common.io.ByteStreams;
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -206,7 +204,7 @@ public class HttpTestHelper
     {
         try (InputStream is = connection.getInputStream())
         {
-            final byte[] bytes = ByteStreams.toByteArray(is);
+            final byte[] bytes = is.readAllBytes();
             if (LOGGER.isTraceEnabled())
             {
                 LOGGER.trace("RESPONSE:" + new String(bytes, UTF_8));
