@@ -20,9 +20,9 @@
  */
 package org.apache.qpid.tests.http.authentication;
 
-import static javax.servlet.http.HttpServletResponse.SC_CREATED;
-import static javax.servlet.http.HttpServletResponse.SC_OK;
-import static javax.servlet.http.HttpServletResponse.SC_UNAUTHORIZED;
+import static jakarta.servlet.http.HttpServletResponse.SC_CREATED;
+import static jakarta.servlet.http.HttpServletResponse.SC_OK;
+import static jakarta.servlet.http.HttpServletResponse.SC_UNAUTHORIZED;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.greaterThan;
 import static org.hamcrest.Matchers.hasKey;
@@ -30,27 +30,26 @@ import static org.hamcrest.Matchers.is;
 import static org.hamcrest.Matchers.not;
 import static org.hamcrest.Matchers.startsWith;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.fail;
 
 import java.io.IOException;
 import java.net.HttpURLConnection;
 import java.net.InetAddress;
-import java.net.SocketException;
 import java.security.KeyStore;
 import java.util.ArrayDeque;
 import java.util.Base64;
-import java.util.Collections;
 import java.util.Deque;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
-import javax.net.ssl.SSLException;
-import javax.net.ssl.SSLHandshakeException;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpServletResponse;
 
 import com.fasterxml.jackson.core.type.TypeReference;
-import org.junit.After;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.management.plugin.HttpManagement;
 import org.apache.qpid.server.model.Port;
@@ -72,13 +71,12 @@ import org.apache.qpid.tests.http.HttpTestHelper;
 
 public class PreemptiveAuthenticationTest extends HttpTestBase
 {
-    private static final TypeReference<String> STRING_TYPE_REF = new TypeReference<String>() {};
+    private static final TypeReference<String> STRING_TYPE_REF = new TypeReference<>() { };
     private static final String STORE_PASSWORD = "password";
 
     private Deque<BaseAction<Void, Exception>> _tearDownActions;
 
-
-    @After
+    @AfterEach
     public void tearDown() throws Exception
     {
         if (_tearDownActions != null)
@@ -106,16 +104,16 @@ public class PreemptiveAuthenticationTest extends HttpTestBase
     @Test
     public void clientAuthSuccess() throws Exception
     {
-        HttpTestHelper helper = configForClientAuth("CN=foo");
+        HttpTestHelper helper = configForClientAuth("CN=localhost");
 
         String userId = helper.getJson("broker/getUser", STRING_TYPE_REF, SC_OK);
-        assertThat(userId, startsWith("foo@"));
+        assertThat(userId, startsWith("localhost@"));
     }
 
     @Test
     public void clientAuthenticationWebManagementConsole() throws Exception
     {
-        HttpTestHelper helper = configForClientAuth("CN=foo");
+        HttpTestHelper helper = configForClientAuth("CN=localhost");
 
         HttpURLConnection authenticateConnection = helper.openManagementConnection(HttpManagement.DEFAULT_LOGIN_URL, "GET");
         authenticateConnection.setInstanceFollowRedirects(false);
@@ -145,7 +143,7 @@ public class PreemptiveAuthenticationTest extends HttpTestBase
         try
         {
             helper.getJson("broker/getUser", STRING_TYPE_REF, SC_OK);
-            fail("Exception not thrown");
+            Assertions.fail("Exception not thrown");
         }
         catch (IOException e)
         {
@@ -212,16 +210,13 @@ public class PreemptiveAuthenticationTest extends HttpTestBase
             helper.setTls(tls);
             assertThat(helper.submitRequest("broker", "GET"), is(equalTo(SC_OK)));
 
-            configHelper.submitRequest("plugin/httpManagement", "POST",
-                                       Collections.<String, Object>singletonMap(authEnabledAttrName, Boolean.FALSE), SC_OK);
+            configHelper.submitRequest("plugin/httpManagement", "POST", Map.of(authEnabledAttrName, Boolean.FALSE), SC_OK);
 
             assertThat(helper.submitRequest("broker", "GET"), is(equalTo(SC_UNAUTHORIZED)));
         }
         finally
         {
-            configHelper.submitRequest("plugin/httpManagement", "POST",
-                                       Collections.<String, Object>singletonMap(authEnabledAttrName, Boolean.TRUE), SC_OK);
-
+            configHelper.submitRequest("plugin/httpManagement", "POST", Map.of(authEnabledAttrName, Boolean.TRUE), SC_OK);
         }
     }
 
@@ -255,7 +250,8 @@ public class PreemptiveAuthenticationTest extends HttpTestBase
 
         final Map<String, Object> truststoreAttr = new HashMap<>();
         truststoreAttr.put(ManagedPeerCertificateTrustStore.TYPE, ManagedPeerCertificateTrustStore.TYPE_NAME);
-        truststoreAttr.put(ManagedPeerCertificateTrustStore.STORED_CERTIFICATES, Collections.singletonList(Base64.getEncoder().encodeToString(clientCertificate)));
+        truststoreAttr.put(ManagedPeerCertificateTrustStore.STORED_CERTIFICATES,
+                List.of(Base64.getEncoder().encodeToString(clientCertificate)));
 
 
         getHelper().submitRequest("truststore/mytruststore","PUT", truststoreAttr, SC_CREATED);
@@ -265,11 +261,11 @@ public class PreemptiveAuthenticationTest extends HttpTestBase
         portAttr.put(Port.TYPE, "HTTP");
         portAttr.put(Port.PORT, 0);
         portAttr.put(Port.AUTHENTICATION_PROVIDER, "myexternal");
-        portAttr.put(Port.PROTOCOLS, Collections.singleton(Protocol.HTTP));
-        portAttr.put(Port.TRANSPORTS, Collections.singleton(Transport.SSL));
+        portAttr.put(Port.PROTOCOLS, Set.of(Protocol.HTTP));
+        portAttr.put(Port.TRANSPORTS, Set.of(Transport.SSL));
         portAttr.put(Port.NEED_CLIENT_AUTH, true);
         portAttr.put(Port.KEY_STORE, "mykeystore");
-        portAttr.put(Port.TRUST_STORES, Collections.singletonList("mytruststore"));
+        portAttr.put(Port.TRUST_STORES, List.of("mytruststore"));
 
         getHelper().submitRequest("port/myport","PUT", portAttr, SC_CREATED);
         deleteActions.add(object -> getHelper().submitRequest("port/myport", "DELETE", SC_OK));
@@ -302,8 +298,8 @@ public class PreemptiveAuthenticationTest extends HttpTestBase
         portAttr.put(Port.TYPE, "HTTP");
         portAttr.put(Port.PORT, 0);
         portAttr.put(Port.AUTHENTICATION_PROVIDER, "myanon");
-        portAttr.put(Port.PROTOCOLS, Collections.singleton(Protocol.HTTP));
-        portAttr.put(Port.TRANSPORTS, Collections.singleton(Transport.TCP));
+        portAttr.put(Port.PROTOCOLS, Set.of(Protocol.HTTP));
+        portAttr.put(Port.TRANSPORTS, Set.of(Transport.TCP));
 
         getHelper().submitRequest("port/myport","PUT", portAttr, SC_CREATED);
         deleteActions.add(object -> getHelper().submitRequest("port/myport", "DELETE", SC_OK));
