@@ -24,7 +24,7 @@ import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
@@ -44,8 +44,10 @@ import javax.jms.TextMessage;
 
 import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.ObjectMapper;
-import org.junit.Before;
-import org.junit.Test;
+
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.model.Protocol;
 import org.apache.qpid.tests.http.HttpRequestConfig;
@@ -58,12 +60,20 @@ public class CompressedMessageContentTest extends HttpTestBase
 {
     private static final String TEST_QUEUE = "testQueue";
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception
     {
-        assumeThat(getProtocol(), is(not(equalTo(Protocol.AMQP_1_0))));
-        getHelper().setTls(true);
+        assumeTrue(is(not(equalTo(Protocol.AMQP_1_0))).matches(getProtocol()));
         getBrokerAdmin().createQueue(TEST_QUEUE);
+        getHelper().createKeyStoreAndSetItOnPort(getFullTestName());
+    }
+
+    @AfterEach
+    public void afterEach() throws Exception
+    {
+        assumeTrue(is(not(equalTo(Protocol.AMQP_1_0))).matches(getProtocol()));
+        getHelper().setAcceptEncoding("Identity");
+        getHelper().removeKeyStoreFromPort(getFullTestName());
     }
 
     @Test
