@@ -19,14 +19,13 @@
  */
 package org.apache.qpid.tests.http.endtoend.message;
 
-import static javax.servlet.http.HttpServletResponse.SC_OK;
+import static jakarta.servlet.http.HttpServletResponse.SC_OK;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.notNullValue;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
-import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 
@@ -37,8 +36,10 @@ import javax.jms.Session;
 import javax.jms.TextMessage;
 
 import com.fasterxml.jackson.core.type.TypeReference;
-import org.junit.Before;
-import org.junit.Test;
+
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.model.VirtualHost;
 import org.apache.qpid.systests.Utils;
@@ -51,16 +52,23 @@ public class ExportImportMessagesTest extends HttpTestBase
 {
     private static final String TEST_QUEUE = "testQueue";
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception
     {
-        getHelper().setTls(true);
+        getHelper().createKeyStoreAndSetItOnPort(getFullTestName());
+    }
+
+    @AfterEach
+    public void afterEach() throws Exception
+    {
+        getHelper().setAcceptEncoding("Identity");
+        getHelper().removeKeyStoreFromPort(getFullTestName());
     }
 
     @Test
     public void exportImport() throws Exception
     {
-        assumeThat(getBrokerAdmin().supportsRestart(), is(true));
+        assumeTrue(getBrokerAdmin().supportsRestart());
 
         getBrokerAdmin().createQueue(TEST_QUEUE);
 
@@ -78,7 +86,7 @@ public class ExportImportMessagesTest extends HttpTestBase
 
         changeVirtualHostState("STOPPED");
 
-        Map<String, Object> importArgs = Collections.singletonMap("source", extractedBytesAsDataUrl);
+        Map<String, Object> importArgs = Map.of("source", extractedBytesAsDataUrl);
         getHelper().postJson("virtualhost/importMessageStore", importArgs, new TypeReference<Void>() {}, SC_OK);
 
         changeVirtualHostState("ACTIVE");
@@ -87,7 +95,7 @@ public class ExportImportMessagesTest extends HttpTestBase
 
     private void changeVirtualHostState(final String desiredState) throws Exception
     {
-        Map<String, Object> attributes = Collections.singletonMap(VirtualHost.DESIRED_STATE, desiredState);
+        Map<String, Object> attributes = Map.of(VirtualHost.DESIRED_STATE, desiredState);
         getHelper().submitRequest("virtualhost", "POST", attributes, SC_OK);
     }
 
