@@ -21,8 +21,8 @@
 
 package org.apache.qpid.tests.http.endtoend.message;
 
-import static javax.servlet.http.HttpServletResponse.SC_CREATED;
-import static javax.servlet.http.HttpServletResponse.SC_OK;
+import static jakarta.servlet.http.HttpServletResponse.SC_CREATED;
+import static jakarta.servlet.http.HttpServletResponse.SC_OK;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.hasEntry;
 import static org.hamcrest.Matchers.is;
@@ -31,7 +31,6 @@ import static org.hamcrest.Matchers.notNullValue;
 import static org.hamcrest.MatcherAssert.assertThat;
 
 import java.io.IOException;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -42,11 +41,12 @@ import java.util.UUID;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpServletResponse;
 
 import com.fasterxml.jackson.core.type.TypeReference;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.model.ConfiguredObject;
 import org.apache.qpid.server.queue.PriorityQueue;
@@ -61,16 +61,16 @@ public class MessageManagementTest extends HttpTestBase
     private static final String INDEX = "index";
     private Set<String> _messageIds;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception
     {
         getBrokerAdmin().createQueue(SOURCE_QUEUE_NAME);
         getBrokerAdmin().createQueue(DESTINATION_QUEUE_NAME);
 
-        getHelper().setTls(true);
+        getHelper().createKeyStoreAndSetItOnPort(getFullTestName());
 
-        final Map<String, Object> odd = Collections.singletonMap(INDEX, 1);
-        final Map<String, Object> even = Collections.singletonMap(INDEX, 0);
+        final Map<String, Object> odd = Map.of(INDEX, 1);
+        final Map<String, Object> even = Map.of(INDEX, 0);
 
         _messageIds = Stream.generate(UUID::randomUUID).map(UUID::toString).limit(4).collect(Collectors.toSet());
 
@@ -82,6 +82,12 @@ public class MessageManagementTest extends HttpTestBase
         }
     }
 
+    @AfterEach
+    public void afterEach() throws Exception
+    {
+        getHelper().removeKeyStoreFromPort(getFullTestName());
+    }
+
     @Test
     public void moveMessagesByInternalIdRange() throws Exception
     {
@@ -170,7 +176,7 @@ public class MessageManagementTest extends HttpTestBase
     {
         final Set<Long> ids = new HashSet<>(getMesssageIds(SOURCE_QUEUE_NAME));
         Iterator<Long> iterator = ids.iterator();
-        Set<Long> toDelete = Collections.singleton(iterator.next());
+        Set<Long> toDelete = Set.of(iterator.next());
         iterator.remove();
 
         Map<String, Object> parameters = new HashMap<>();
@@ -207,7 +213,7 @@ public class MessageManagementTest extends HttpTestBase
     public void testClearQueue() throws Exception
     {
         getHelper().submitRequest(String.format("queue/%s/clearQueue", SOURCE_QUEUE_NAME), "POST",
-                                  Collections.emptyMap(), HttpServletResponse.SC_OK);
+                Map.of(), HttpServletResponse.SC_OK);
 
         assertThat(getBrokerAdmin().getQueueDepthMessages(SOURCE_QUEUE_NAME), is(equalTo(0)));
     }
@@ -336,7 +342,7 @@ public class MessageManagementTest extends HttpTestBase
 
         getHelper().submitRequest("virtualhost/publishMessage",
                                   "POST",
-                                  Collections.singletonMap("message", messageBody),
+                                  Map.of("message", messageBody),
                                   SC_OK);
     }
 
@@ -345,12 +351,12 @@ public class MessageManagementTest extends HttpTestBase
         final Map<String, Object> messageBody = new HashMap<>();
         messageBody.put("address", queueName);
         messageBody.put("messageId", messageId);
-        messageBody.put("headers", Collections.singletonMap("id", messageId));
+        messageBody.put("headers", Map.of("id", messageId));
         messageBody.put("priority", priority);
 
         getHelper().submitRequest("virtualhost/publishMessage",
                                   "POST",
-                                  Collections.singletonMap("message", messageBody),
+                                  Map.of("message", messageBody),
                                   SC_OK);
     }
 
