@@ -21,7 +21,7 @@
 
 package org.apache.qpid.tests.http.endtoend.message;
 
-import static javax.servlet.http.HttpServletResponse.SC_OK;
+import static jakarta.servlet.http.HttpServletResponse.SC_OK;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.greaterThanOrEqualTo;
 import static org.hamcrest.Matchers.is;
@@ -30,10 +30,9 @@ import static org.hamcrest.Matchers.notNullValue;
 import static org.hamcrest.Matchers.nullValue;
 import static org.hamcrest.Matchers.typeCompatibleWith;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.List;
@@ -55,9 +54,9 @@ import javax.jms.StreamMessage;
 import javax.jms.TextMessage;
 
 import com.fasterxml.jackson.core.type.TypeReference;
-import com.google.common.base.Strings;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.model.Protocol;
 import org.apache.qpid.tests.http.HttpRequestConfig;
@@ -67,24 +66,21 @@ import org.apache.qpid.tests.http.HttpTestBase;
 public class MessageTest extends HttpTestBase
 {
     private static final String QUEUE_NAME = "myqueue";
-    private static final TypeReference<List<Map<String, Object>>> LIST_MAP_TYPE_REF =
-            new TypeReference<List<Map<String, Object>>>()
-            {
-            };
-    private static final TypeReference<Map<String, Object>> MAP_TYPE_REF =
-            new TypeReference<Map<String, Object>>()
-            {
-            };
-    private static final TypeReference<List<Object>> LIST_TYPE_REF =
-            new TypeReference<List<Object>>()
-            {
-            };
+    private static final TypeReference<List<Map<String, Object>>> LIST_MAP_TYPE_REF = new TypeReference<>() { };
+    private static final TypeReference<Map<String, Object>> MAP_TYPE_REF = new TypeReference<>() { };
+    private static final TypeReference<List<Object>> LIST_TYPE_REF = new TypeReference<>() { };
 
-    @Before
-    public void setUp()
+    @BeforeEach
+    public void setUp() throws Exception
     {
         getBrokerAdmin().createQueue(QUEUE_NAME);
-        getHelper().setTls(true);
+        getHelper().createKeyStoreAndSetItOnPort(getFullTestName());
+    }
+
+    @AfterEach
+    public void afterEach() throws Exception
+    {
+        getHelper().removeKeyStoreFromPort(getFullTestName());
     }
 
     @Test
@@ -108,8 +104,7 @@ public class MessageTest extends HttpTestBase
         }
 
         List<Map<String, Object>> messages = getHelper().postJson("queue/myqueue/getMessageInfo",
-                                                                  Collections.singletonMap("includeHeaders",
-                                                                                           Boolean.TRUE),
+                                                                  Map.of("includeHeaders", Boolean.TRUE),
                                                                   LIST_MAP_TYPE_REF, SC_OK);
         assertThat(messages.size(), is(equalTo(1)));
 
@@ -139,8 +134,7 @@ public class MessageTest extends HttpTestBase
         }
 
         List<Map<String, Object>> messages = getHelper().postJson("queue/myqueue/getMessageInfo",
-                                                                  Collections.singletonMap("includeHeaders",
-                                                                                           Boolean.FALSE),
+                                                                  Map.of("includeHeaders", Boolean.FALSE),
                                                                   LIST_MAP_TYPE_REF, SC_OK);
         assertThat(messages.size(), is(equalTo(1)));
 
@@ -165,8 +159,7 @@ public class MessageTest extends HttpTestBase
             producer.send(jmsMessage);
 
             List<Map<String, Object>> messages = getHelper().postJson("queue/myqueue/getMessageInfo",
-                                                                      Collections.singletonMap("includeHeaders",
-                                                                                               Boolean.FALSE),
+                                                                      Map.of("includeHeaders", Boolean.FALSE),
                                                                       LIST_MAP_TYPE_REF, SC_OK);
             assertThat(messages.size(), is(equalTo(1)));
             Map<String, Object> message = messages.get(0);
@@ -177,10 +170,8 @@ public class MessageTest extends HttpTestBase
             jmsMessage = consumer.receive(getReceiveTimeout());
             assertThat(jmsMessage, is(notNullValue()));
 
-            messages = getHelper().postJson("queue/myqueue/getMessageInfo",
-                                                                      Collections.singletonMap("includeHeaders",
-                                                                                               Boolean.FALSE),
-                                                                      LIST_MAP_TYPE_REF, SC_OK);
+            messages = getHelper().postJson("queue/myqueue/getMessageInfo", Map.of("includeHeaders", Boolean.FALSE),
+                    LIST_MAP_TYPE_REF, SC_OK);
             assertThat(messages.size(), is(equalTo(1)));
 
             message = messages.get(0);
@@ -214,8 +205,7 @@ public class MessageTest extends HttpTestBase
         }
 
         List<Map<String, Object>> messages = getHelper().postJson("queue/myqueue/getMessageInfo",
-                                                                  Collections.singletonMap("includeHeaders",
-                                                                                           Boolean.TRUE),
+                                                                  Map.of("includeHeaders", Boolean.TRUE),
                                                                   LIST_MAP_TYPE_REF, SC_OK);
         assertThat(messages.size(), is(equalTo(1)));
         Map<String, Object> message = messages.get(0);
@@ -252,8 +242,7 @@ public class MessageTest extends HttpTestBase
         }
 
         List<Map<String, Object>> messages = getHelper().postJson("queue/myqueue/getMessageInfo",
-                                                                  Collections.singletonMap("includeHeaders",
-                                                                                           Boolean.TRUE),
+                                                                  Map.of("includeHeaders", Boolean.TRUE),
                                                                   LIST_MAP_TYPE_REF, SC_OK);
         assertThat(messages.size(), is(equalTo(1)));
         Map<String, Object> message = messages.get(0);
@@ -293,8 +282,7 @@ public class MessageTest extends HttpTestBase
         }
 
         List<Map<String, Object>> messages = getHelper().postJson("queue/myqueue/getMessageInfo",
-                                                                  Collections.singletonMap("includeHeaders",
-                                                                                           Boolean.TRUE),
+                                                                  Map.of("includeHeaders", Boolean.TRUE),
                                                                   LIST_MAP_TYPE_REF, SC_OK);
         assertThat(messages.size(), is(equalTo(1)));
         Map<String, Object> message = messages.get(0);
@@ -303,8 +291,7 @@ public class MessageTest extends HttpTestBase
         byte[] receivedContent = getHelper().getBytes(String.format(
                 "queue/myqueue/getMessageContent?messageId=%d", messageId));
 
-        assumeThat("AMQP1.0 messages return the AMQP type",
-                   getProtocol(), is(not(equalTo(Protocol.AMQP_1_0))));
+        assumeTrue(is(not(equalTo(Protocol.AMQP_1_0))).matches(getProtocol()), "AMQP1.0 messages return the AMQP type");
 
         assertThat(receivedContent, is(equalTo(content)));
     }
@@ -317,7 +304,7 @@ public class MessageTest extends HttpTestBase
 
         getHelper().submitRequest("virtualhost/publishMessage",
                                   "POST",
-                                  Collections.singletonMap("message", messageBody),
+                                  Map.of("message", messageBody),
                                   SC_OK);
 
         Connection connection = getConnection();
@@ -340,7 +327,7 @@ public class MessageTest extends HttpTestBase
     public void publishMessageApplicationHeaders() throws Exception
     {
         final String stringPropValue = "mystring";
-        final String longStringPropValue = Strings.repeat("*", 256);
+        final String longStringPropValue = "*".repeat(256);
         final Map<String, Object> headers = new HashMap<>();
         headers.put("stringprop", stringPropValue);
         headers.put("longstringprop", longStringPropValue);
@@ -354,7 +341,7 @@ public class MessageTest extends HttpTestBase
 
         getHelper().submitRequest("virtualhost/publishMessage",
                                   "POST",
-                                  Collections.singletonMap("message", messageBody),
+                                  Map.of("message", messageBody),
                                   SC_OK);
 
         Connection connection = getConnection();
@@ -380,7 +367,7 @@ public class MessageTest extends HttpTestBase
     @Test
     public void publishMessageHeaders() throws Exception
     {
-        final String messageId = "ID:" + UUID.randomUUID().toString();
+        final String messageId = "ID:" + UUID.randomUUID();
         final long expiration = TimeUnit.DAYS.toMillis(1) + System.currentTimeMillis();
 
         Map<String, Object> messageBody = new HashMap<>();
@@ -390,7 +377,7 @@ public class MessageTest extends HttpTestBase
 
         getHelper().submitRequest("virtualhost/publishMessage",
                                   "POST",
-                                  Collections.singletonMap("message", messageBody),
+                                  Map.of("message", messageBody),
                                   SC_OK);
 
         Connection connection = getConnection();
@@ -463,7 +450,7 @@ public class MessageTest extends HttpTestBase
 
         getHelper().submitRequest("virtualhost/publishMessage",
                                   "POST",
-                                  Collections.singletonMap("message", messageBody),
+                                  Map.of("message", messageBody),
                                   SC_OK);
 
         Connection connection = getConnection();
