@@ -21,24 +21,24 @@
 package org.apache.qpid.tests.http.endtoend.port;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
-import static javax.servlet.http.HttpServletResponse.SC_CREATED;
-import static javax.servlet.http.HttpServletResponse.SC_OK;
+import static jakarta.servlet.http.HttpServletResponse.SC_CREATED;
+import static jakarta.servlet.http.HttpServletResponse.SC_OK;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.instanceOf;
 import static org.hamcrest.Matchers.notNullValue;
 import static org.hamcrest.core.Is.is;
-import static org.junit.Assert.assertEquals;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.io.File;
 import java.io.IOException;
 import java.nio.file.Path;
 import java.security.cert.X509Certificate;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Set;
 
 import javax.jms.Connection;
 import javax.jms.JMSException;
@@ -50,9 +50,10 @@ import javax.jms.TextMessage;
 import javax.naming.NamingException;
 
 import com.fasterxml.jackson.core.type.TypeReference;
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Test;
+
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
 import org.apache.qpid.server.model.ConfiguredObject;
 import org.apache.qpid.server.model.Port;
@@ -72,13 +73,11 @@ import org.apache.qpid.tests.http.HttpTestHelper;
 
 public class PortTest extends HttpTestBase
 {
-    @ClassRule
+    @RegisterExtension
     public static final TlsResource TLS_RESOURCE = new TlsResource();
 
     private static final String QUEUE_NAME = "testQueue";
-    private static final TypeReference<Boolean> BOOLEAN = new TypeReference<Boolean>()
-    {
-    };
+    private static final TypeReference<Boolean> BOOLEAN = new TypeReference<>() { };
     private static final String CERTIFICATE_ALIAS = "certificate";
     private String _portName;
     private String _authenticationProvider;
@@ -86,10 +85,9 @@ public class PortTest extends HttpTestBase
 
     private File _storeFile;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception
     {
-
         _portName = getTestName();
         _authenticationProvider = _portName + "AuthenticationProvider";
         _keyStoreName = _portName + "KeyStore";
@@ -176,7 +174,7 @@ public class PortTest extends HttpTestBase
     @Test
     public void testSwapKeyStoreAndUpdateTlsOnWssPort() throws Exception
     {
-        assumeThat(getProtocol(), is(equalTo(Protocol.AMQP_1_0)));
+        assumeTrue(is(equalTo(Protocol.AMQP_1_0)).matches(getProtocol()));
         final int port = createPort(Transport.WSS);
         final Connection connection = createConnectionBuilder(port, _storeFile.getAbsolutePath())
                 .setTransport("amqpws").build();
@@ -234,8 +232,7 @@ public class PortTest extends HttpTestBase
 
     private void createAnonymousAuthenticationProvider() throws IOException
     {
-        final Map<String, Object> data = Collections.singletonMap(ConfiguredObject.TYPE,
-                                                                  AnonymousAuthenticationManager.PROVIDER_TYPE);
+        final Map<String, Object> data = Map.of(ConfiguredObject.TYPE, AnonymousAuthenticationManager.PROVIDER_TYPE);
         getHelper().submitRequest("authenticationprovider/" + _authenticationProvider, "PUT", data, SC_CREATED);
     }
 
@@ -290,7 +287,7 @@ public class PortTest extends HttpTestBase
         port.put(Port.TYPE, type);
         port.put(Port.PORT, 0);
         port.put(Port.KEY_STORE, _keyStoreName);
-        port.put(Port.TRANSPORTS, Collections.singleton(transport));
+        port.put(Port.TRANSPORTS, Set.of(transport));
 
         getHelper().submitRequest("port/" + _portName, "PUT", port, SC_CREATED);
 
@@ -308,7 +305,7 @@ public class PortTest extends HttpTestBase
 
     private KeyCertificatePair generateSelfSignedCertificate() throws Exception
     {
-        return TlsResourceBuilder.createSelfSigned("CN=foo");
+        return TlsResourceBuilder.createSelfSigned("CN=localhost");
     }
 
     private void assertMessage(final Message messageA, final String a) throws JMSException
@@ -323,8 +320,7 @@ public class PortTest extends HttpTestBase
         String newKeyStoreName = _keyStoreName + "_2";
         final KeyCertificatePair keyCertPair = generateSelfSignedCertificate();
         submitKeyStoreAttributes(newKeyStoreName, SC_CREATED, keyCertPair);
-        getHelper().submitRequest("port/" + _portName, "POST",
-                                  Collections.<String, Object>singletonMap(Port.KEY_STORE, newKeyStoreName), SC_OK);
+        getHelper().submitRequest("port/" + _portName,"POST", Map.of(Port.KEY_STORE, newKeyStoreName), SC_OK);
         updatePortTls();
         return createTrustStore(keyCertPair);
     }
@@ -339,20 +335,14 @@ public class PortTest extends HttpTestBase
 
     private File createTrustStore(final KeyCertificatePair keyCertPair) throws Exception
     {
-        CertificateEntry entry = new CertificateEntry(
-                CERTIFICATE_ALIAS,
-                keyCertPair.getCertificate());
-        Path keyStore = TLS_RESOURCE.createKeyStore(entry);
+        final CertificateEntry entry = new CertificateEntry(CERTIFICATE_ALIAS, keyCertPair.getCertificate());
+        final Path keyStore = TLS_RESOURCE.createKeyStore(entry);
         return keyStore.toFile();
     }
 
     private void updatePortTls() throws Exception
     {
-        final boolean response = getHelper().postJson("port/" + _portName + "/updateTLS",
-                                                      Collections.emptyMap(),
-                                                      BOOLEAN,
-                                                      SC_OK);
+        final boolean response = getHelper().postJson("port/" + _portName + "/updateTLS", Map.of(), BOOLEAN, SC_OK);
         assertTrue(response);
-
     }
 }
