@@ -19,14 +19,13 @@
  */
 package org.apache.qpid.tests.http.endtoend.state;
 
-import static javax.servlet.http.HttpServletResponse.SC_OK;
+import static jakarta.servlet.http.HttpServletResponse.SC_OK;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.notNullValue;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
-import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 
@@ -37,8 +36,9 @@ import javax.jms.Session;
 import javax.jms.TextMessage;
 
 import com.fasterxml.jackson.core.type.TypeReference;
-import org.junit.Before;
-import org.junit.Test;
+
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.model.ConfiguredObject;
 import org.apache.qpid.systests.Utils;
@@ -49,15 +49,15 @@ public class VirtualHostRecoveryTest extends HttpTestBase
 {
     private static final String TEST_QUEUE = "testQueue";
 
-    @Before
-    public void setUp() throws Exception
+    @BeforeEach
+    public void setUp()
     {
+        assumeTrue(getBrokerAdmin().supportsRestart());
         getBrokerAdmin().createQueue(TEST_QUEUE);
-        assumeThat(getBrokerAdmin().supportsRestart(), is(true));
     }
 
     @Test
-    @HttpRequestConfig(useVirtualHostAsHost = true)
+    @HttpRequestConfig()
     public void virtualHostRestart() throws Exception
     {
         final TextMessage sentMessage = putMessageOnQueue();
@@ -125,15 +125,14 @@ public class VirtualHostRecoveryTest extends HttpTestBase
 
     private void changeState(final String url, final String desiredState) throws Exception
     {
-        Map<String, Object> attributes = Collections.singletonMap(ConfiguredObject.DESIRED_STATE, desiredState);
+        Map<String, Object> attributes = Map.of(ConfiguredObject.DESIRED_STATE, desiredState);
         getHelper().submitRequest(url, "POST", attributes, SC_OK);
     }
 
     private void assertState(final String url, final String expectedActualState) throws Exception
     {
-        Map<String, Object> object = getHelper().getJson(url, new TypeReference<Map<String, Object>>() {}, SC_OK);
+        Map<String, Object> object = getHelper().getJson(url, new TypeReference<>() {}, SC_OK);
         final String actualState = (String) object.get(ConfiguredObject.STATE);
         assertThat(actualState, is(equalTo(expectedActualState)));
     }
-
 }
