@@ -21,8 +21,8 @@
 package org.apache.qpid.tests.http.rest.model;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
-import static javax.servlet.http.HttpServletResponse.SC_NOT_FOUND;
-import static javax.servlet.http.HttpServletResponse.SC_OK;
+import static jakarta.servlet.http.HttpServletResponse.SC_NOT_FOUND;
+import static jakarta.servlet.http.HttpServletResponse.SC_OK;
 import static org.apache.qpid.server.management.plugin.servlet.rest.AbstractServlet.SC_UNPROCESSABLE_ENTITY;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.is;
@@ -30,15 +30,16 @@ import static org.hamcrest.CoreMatchers.notNullValue;
 import static org.hamcrest.Matchers.greaterThan;
 import static org.hamcrest.Matchers.nullValue;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.fail;
 
 import java.io.FileNotFoundException;
-import java.util.Collections;
 import java.util.LinkedHashMap;
+import java.util.List;
 import java.util.Map;
 
 import com.fasterxml.jackson.core.type.TypeReference;
-import org.junit.Test;
+
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.tests.http.HttpRequestConfig;
 import org.apache.qpid.tests.http.HttpTestBase;
@@ -57,7 +58,7 @@ public class OperationTest extends HttpTestBase
     public void invokeNoParameters() throws Exception
     {
         Map<String, Object> response = getHelper().postJson("virtualhost/getStatistics",
-                                                            Collections.emptyMap(),
+                                                            Map.of(),
                                                             MAP_TYPE_REF, SC_OK);
         assertThat(response.size(), is(greaterThan(1)));
     }
@@ -65,8 +66,7 @@ public class OperationTest extends HttpTestBase
     @Test
     public void invokeWithParameters() throws Exception
     {
-        Map<Object, Object> params = Collections.singletonMap("statistics",
-                                                              Collections.singletonList("connectionCount"));
+        Map<Object, Object> params = Map.of("statistics", List.of("connectionCount"));
 
         Map<String, Object> response = getHelper().postJson("virtualhost/getStatistics",
                                                             params,
@@ -85,7 +85,7 @@ public class OperationTest extends HttpTestBase
     @Test
     public void invalidParameter() throws Exception
     {
-        Map<String, Object> params = Collections.singletonMap("unknown", Collections.emptyMap());
+        Map<String, Object> params = Map.of("unknown", Map.of());
 
         getHelper().submitRequest("virtualhost/getStatistics", "POST", params, SC_UNPROCESSABLE_ENTITY);
     }
@@ -93,7 +93,7 @@ public class OperationTest extends HttpTestBase
     @Test
     public void operationNotFound() throws Exception
     {
-        getHelper().submitRequest("virtualhost/notfound", "POST", Collections.emptyMap(), SC_NOT_FOUND);
+        getHelper().submitRequest("virtualhost/notfound", "POST", Map.of(), SC_NOT_FOUND);
     }
 
     @Test
@@ -101,7 +101,7 @@ public class OperationTest extends HttpTestBase
     {
         final HttpTestHelper brokerHelper = new HttpTestHelper(getBrokerAdmin());
         final Void response = brokerHelper.postJson("broker/performGC",
-                                                    Collections.emptyMap(),
+                                                    Map.of(),
                                                     new TypeReference<Void>()
                                                     {
                                                     },
@@ -116,12 +116,13 @@ public class OperationTest extends HttpTestBase
         try
         {
             getHelper().postJson("broker/performGC",
-                                 Collections.emptyMap(),
+                                 Map.of(),
                                  new TypeReference<Void>()
                                  {
                                  },
                                  SC_NOT_FOUND);
-            fail("The request is executed against root object VirtualHost. Thus, any broker request should fail.");
+            Assertions.fail(
+                    "The request is executed against root object VirtualHost. Thus, any broker request should fail.");
         }
         catch (FileNotFoundException e)
         {
@@ -138,6 +139,5 @@ public class OperationTest extends HttpTestBase
                 "broker/getThreadStackTraces?contentDispositionAttachmentFilename=stack-traces.txt&appendToLog=false");
         assertThat(response, is(notNullValue()));
         assertThat(new String(response, UTF_8).contains("Full thread dump captured"), is(equalTo(true)));
-
     }
 }
